# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtCore
import PyQt5.QtWidgets
import QT4FormWidgets as QT4FormWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtWidgets as QtWidgets
from typing import ClassVar, Set, Tuple

class ExtendedProductInfoItem(PyQt5.QtWidgets.QFrame):
    aboutToShow: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, caption, parent) -> None: ...
    def _ExtendedProductInfoItem__updateState(self): ...
    def setText(self, text): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import UI4.FormMaster.EnableableParameterPolicy as EnableableParameterPolicy
import UI4.Util.ManipulatorManager as ManipulatorManager
import Nodes3DAPI as Nodes3DAPI
import UI4.FormMaster.ParameterPolicy as ParameterPolicy
from typing import Set, Tuple

NODE_TYPES: list
nodeType: str



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import AssetAPI as AssetAPI
import UI4.Widgets.SceneGraphView.DataRoles as DataRoles
import UI4.Widgets.FilterPopups as FilterPopups
import NodegraphAPI
import Nodes3DAPI as Nodes3DAPI
import PyQt5.QtCore
import PyQt5.QtGui
import PyQt5.QtWidgets
import QT4FormWidgets as QT4FormWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import RenderingAPI.RenderPlugins as RenderPlugins
import RenderingAPI as RenderingAPI
import UI4.Util.ScenegraphIconManager as ScenegraphIconManager
import UI4.Widgets.FilterPopups
import UI4.Widgets.SceneGraphView.Bridge
import Utils as Utils
import typing
from UI4.Util.UndoGrouping import UndoContextGuard as UndoContextGuard
from UI4.Widgets.FilterPopups import LookFileMaterialFilterPopup as LookFileMaterialFilterPopup
from UI4.Widgets.SceneGraphView.ColumnDataType import RegisterDataType as RegisterDataType
from UI4.Widgets.SceneGraphView.ItemDelegates.BaseItemDelegate import BaseItemDelegate as BaseItemDelegate
from UI4.Widgets.SceneGraphView.ItemDelegates.ParameterItemDelegate import ParameterItemDelegate as ParameterItemDelegate
from Utils.Decorators import deprecated as deprecated
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class ShaderItemDelegate(ParameterItemDelegate):
    class MaterialSelectionPopupFrame(PyQt5.QtWidgets.QFrame):
        def __init__(self, valuePolicy: ValuePolicy, lookFileAsset: str, lookFileMaterialPath: str, parent: Incomplete | None = ...) -> None: ...
        def _MaterialSelectionPopupFrame__lookFileChangedCallback(self, *args, **kwds): ...
        def _MaterialSelectionPopupFrame__on_lookFileMaterialFilterPopup_itemChosen(self, item, meta: Incomplete | None = ...): ...
        def _MaterialSelectionPopupFrame__on_shaderFilterPopup_itemChosen(self, item): ...
        def getShaderFilterPopup(self): ...
        def popup(self, globalPos): ...
        def setLookFileMaterialAssignmentCallback(self, callback, locationPath): ...
        def setMasterMaterialsRequestCallback(self, callback, locationPath): ...
        def setTemplateMaterialsRequestCallback(self, callback, locationPath): ...

    class ShaderFilterPopup(UI4.Widgets.FilterPopups.ShaderFilterPopup):
        class ItemDelegate(BaseItemDelegate):
            kTemplateMaterialColor: ClassVar[PyQt5.QtGui.QColor] = ...
            def initStyleOption(self, option: PyQt5.QtWidgets.QStyleOptionViewItem, index: PyQt5.QtCore.QModelIndex): ...
        def __init__(self, valuePolicy: ValuePolicy, parent: Incomplete | None = ...) -> None: ...
        def _refreshContents(self): ...
        def setMasterMaterialsRequestCallback(self, callback, locationPath): ...
        def setTemplateMaterialsRequestCallback(self, callback: typing.Callable, locationPath: str): ...
    AffectsOtherItemDelegates: ClassVar[bool] = ...
    OnParameterSetCallbackType: ClassVar[str] = ...
    kTemplateMaterialKey: ClassVar[str] = ...
    def __init__(self, bridge: Bridge[UI4.Widgets.SceneGraphView.Bridge.Bridge], treeWidget: PyQt5.QtWidgets.QTreeWidget, parent: Incomplete | None = ...) -> None: ...
    def _ShaderItemDelegate__assignTemplateMaterialToPackages(self, templateMaterialLocationPath: str, locationPaths: list[str]): ...
    def _ShaderItemDelegate__getShaderNodeAndParameter(self, index: PyQt5.QtCore.QModelIndex) -> tuple[NodegraphAPI.Node, NodegraphAPI.Parameter] | Tuple[None, None]: ...
    def _ShaderItemDelegate__getShaderSubTypeForLocation(self, locationPath: str) -> str | None: ...
    def _ShaderItemDelegate__on_removeAllShadersAction_triggered(self): ...
    def _ShaderItemDelegate__on_shaderFilterPopup_itemChosen(self, itemText: str, itemMeta: str): ...
    def _ShaderItemDelegate__on_shaderTypeAction_triggered(self): ...
    def _ShaderItemDelegate__on_unassignTemplateMaterialsAction_triggered(self): ...
    def _ShaderItemDelegate__removeAllShadersFromSelectedPackages(self): ...
    def _ShaderItemDelegate__setShaderForSelectedPackages(self, shaderType: str, shaderName: str): ...
    def _ShaderItemDelegate__setTemplateMaterialForSelectedPackages(self, templateMaterialLocationPath: str | None): ...
    def _ShaderItemDelegate__unassignTemplateMaterialsFromPackages(self, locationPaths: list[str]): ...
    def createContextMenu(self, index: PyQt5.QtCore.QModelIndex, selectedItems: list[PyQt5.QtWidgets.QTreeWidgetItem]) -> PyQt5.QtWidgets.QMenu | None: ...
    def createEditor(self, parent: PyQt5.QtWidgets.QWidget, option: PyQt5.QtWidgets.QStyleOptionViewItem, index: PyQt5.QtCore.QModelIndex) -> PyQt5.QtWidgets.QWidget | None: ...
    def initStyleOption(self, option: PyQt5.QtWidgets.QStyleOptionViewItem, index: PyQt5.QtCore.QModelIndex): ...
    def setLookFileMaterialCallback(self, lookFileMaterialAssignmentCallback: typing.Callable | None): ...
    def setMasterMaterialCallbacks(self, masterMaterialsRequestCallback: typing.Callable, masterMaterialAssignmentCallback: typing.Callable): ...
    def setTemplateMaterialCallbacks(self, templateMaterialsRequestCallback: typing.Callable, templateMaterialAssignmentCallback: typing.Callable): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import UI4.Util.IconManager as IconManager
import PyQt5.QtWidgets
import PyQt5.QtWidgets as QtWidgets
from UI4.Widgets.ToolbarButton import ToolbarButton as ToolbarButton
from typing import Set, Tuple

class EditWrenchButton(ToolbarButton):
    def __init__(self, tooltip: str, parent: PyQt5.QtWidgets.QWidget) -> None: ...
    def _EditWrenchButton__on_menu_aboutToShow(self): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyFnGeolibProducers
from GeoAPI import GetCameraInfo as GetCameraInfo, GetLocalToScreenMatrix as GetLocalToScreenMatrix, GetProjectionMatrix as GetProjectionMatrix
from typing import Set, Tuple, overload

def ConvertPointListToNDC(producer: PyFnGeolibProducers.GeometryProducer, cameraName: str, points: list[float]) -> list[float]: ...
def ExpandArchPath(inputString: str) -> str: ...
def FlushRendererOutputCaches() -> None: ...
def GetPixelAreaThroughCamera(producer: PyFnGeolibProducers.GeometryProducer, cameraName: str, resolution: str) -> int: ...
@overload
def ProcessTilePath(outputFile: str, tileData: list[int]) -> str: ...
@overload
def ProcessTilePath(outputFile: str, tileData: list[float]) -> str: ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyFnAttribute
from typing import Set, Tuple

def combineLayeredMaterialOverrides(attr1: PyFnAttribute.Attribute, attr2: PyFnAttribute.Attribute, attr3: PyFnAttribute.Attribute) -> None: ...
def extractMaterialReferences(attr: PyFnAttribute.GroupAttribute, processHints: bool = ...) -> PyFnAttribute.GroupAttribute: ...
def getLayerPrefixesFromMaterial(attr: PyFnAttribute.GroupAttribute) -> PyFnAttribute.StringAttribute: ...
def resolveDeferredNetworkOps(attr: PyFnAttribute.GroupAttribute) -> PyFnAttribute.GroupAttribute: ...
def resolveMaterialLayers(attr: PyFnAttribute.GroupAttribute, processHints: bool = ...) -> PyFnAttribute.GroupAttribute: ...
def resolveMaterialReferences(attr: PyFnAttribute.GroupAttribute, processHints: bool = ...) -> PyFnAttribute.GroupAttribute: ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtWidgets as QtWidgets
import UI4 as UI4
from typing import Set, Tuple

class AnimationPathVisibilityCheckBox(PyQt5.QtWidgets.QCheckBox):
    def __init__(self, *args) -> None: ...
    def _AnimationPathVisibilityCheckBox__stateChanged_CB(self, state): ...

class ManipulatorVisibilityCheckBox(PyQt5.QtWidgets.QCheckBox):
    def __init__(self, policy, monitorWidget, *args) -> None: ...
    def _ManipulatorVisibilityCheckBox__stateChanged_CB(self, state): ...

def AddManipulatorMenuActions(menu, monitorWidget): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import UI4.FormMaster.EnableableParameterPolicy as EnableableParameterPolicy
import UI4.FormMaster.HintsDelegate as HintsDelegate
import UI4.Util.ManipulatorManager as ManipulatorManager
import UI4.FormMaster.ParameterPolicy as ParameterPolicy
from UI4.FormMaster.NodeHints.Common2D import AddCommon2DToNodeHints as AddCommon2DToNodeHints, GetAngleNumberDict as GetAngleNumberDict, GetAspectRatioNumberDict as GetAspectRatioNumberDict
from typing import Set, Tuple

AnisotropicParamHints: dict
ClampOutputParamHints: dict
DownFilterParamHints: dict
GroupFilterParamHints: dict
HighlightCompensationParamHints: dict
MotionBlurEnableParamHints: dict
MotionBlurGroupParamHints: dict
MotionBlurNumSamplesParamHints: dict
MotionBlurOnlyApplyMotionParamHints: dict
MotionBlurShutterParamHints: dict
UpFilterParamHints: dict
_NodeHints: dict
_NodeName: str



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyFnAttribute
import PyFnGeolib
from typing import Set, Tuple

class Traversal:
    def __init__(self, client: PyFnGeolib.GeolibRuntimeClient, rootLocation: str) -> None: ...
    def getLocationData(self) -> PyFnGeolib.LocationData: ...
    def getLocationPath(self) -> str: ...
    def getRelativeLocationPath(self) -> str: ...
    def next(self) -> None: ...
    def skipChildren(self) -> None: ...
    def valid(self) -> bool: ...

def GetScenegraphAsAttr(client: PyFnGeolib.GeolibRuntimeClient, rootLocation: str) -> PyFnAttribute.GroupAttribute: ...
def GetScenegraphAsPrettyText(client: PyFnGeolib.GeolibRuntimeClient, rootLocation: str) -> str: ...
def GetScenegraphAttrAsPrettyText(attr: PyFnAttribute.GroupAttribute, rootLocation: str) -> str: ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyFnAttribute as FnAttribute
import NodegraphAPI as NodegraphAPI
import PackageSuperToolAPI.Packages
import PackageSuperToolAPI.Policies as Policies
import PyQt5.QtCore
import QT4FormWidgets
import PyQt5.QtCore as QtCore
import Utils as Utils
from PackageSuperToolAPI.UIDelegate import UIDelegate as UIDelegate
from Utils.Decorators import deprecated as deprecated
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class EditUIDelegate(UIDelegate):
    def __init__(self, package: Incomplete | None = ..., locationPath: Incomplete | None = ...) -> None: ...
    def _EditUIDelegate__switchToParameterPolicy(self, potentialParameterProxyPolicy): ...
    def getLocationPath(self): ...
    def initPotentialParameterPolicy(self, parentPolicy: ValuePolicy, attrName: str): ...
    def isAdopted(self) -> bool: ...
    def setAdopted(self, package): ...
    def setNotAdopted(self, locationAttributes): ...
    def updateAttributes(self, locationAttributes): ...

class UIDelegate(PyQt5.QtCore.QObject):
    AddPackageActionHash: ClassVar[None] = ...
    DefaultShortcut: ClassVar[None] = ...
    def __init__(self, package: object) -> None: ...
    @classmethod
    def getKeyboardShortcuts(cls) -> None: ...
    def getMenuActions(self) -> list[tuple[str, str, bool]]: ...
    def getPackage(self) -> PackageSuperToolAPI.Packages.Package: ...
    def getPackageNode(self) -> NodegraphAPI.Node: ...
    def getReferencedNode(self, paramName: str) -> NodegraphAPI.Node | None: ...
    def getTabPolicy(self, tabName: str) -> QT4FormWidgets.AbstractValuePolicy | None: ...

def CreateUIDelegate(package: object) -> UIDelegate: ...
def GetDelegateClassForPackageClass(packageClass): ...
def GetUIDelegate(package): ...
def GetUIDelegateClassForPackageClass(packageClass: type) -> type: ...
def RegisterUIDelegate(packageClass, uiDelegateClass): ...
def RegisterUIDelegateClass(packageClass: type, uiDelegateClass: type): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import NodegraphAPI
import QT4FormWidgets as QT4FormWidgets
import QT4FormWidgets.InputWidgets
import Utils as Utils
from typing import Set, Tuple

class PortNameLineEdit(QT4FormWidgets.InputWidgets.InputLineEdit):
    def __init__(self, node: NodegraphAPI.Node, portIndex, *args) -> None: ...
    def _PortNameLineEdit__renameInputPort_CB(self, messageType, nodePtr, **kwargs): ...
    def _PortNameLineEdit__updateText(self): ...
    def doReturnPressed(self): ...
    def getNode(self) -> NodegraphAPI.Node: ...
    def getPortIndex(self): ...
    def setIndex(self, index): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from . import BaseLiveRenderAction as BaseLiveRenderAction, BaseProxyLoader as BaseProxyLoader, BaseViewerPluginExtension as BaseViewerPluginExtension
from typing import Set, Tuple



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import ConfigurationAPI_cmodule as Configuration
import PyQt5.QtCore as QtCore
from _typeshed import Incomplete
from typing import Set, Tuple

DEFAULT_SOURCE_NAME: str
REMOTE_HOST: str
SOURCES: dict

class _Source:
    def __init__(self, title, **urls) -> None: ...
    def get3DelightForKatanaURL(self) -> str: ...
    def getDevGuideURL(self, documentPath: str = ...) -> str: ...
    def getNodeHelpURL(self, nodeTypeName: str) -> str: ...
    def getOnlineHelpURL(self, cshid: Incomplete | None = ...) -> str: ...

def GetSource(sourceName: Incomplete | None = ...) -> _Source: ...
def GetStyleSheetsPath() -> str: ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import UI4.Util.IconManager as IconManager
import PyQt5.QtCore
import PyQt5.QtGui
import PyQt5.QtWidgets
import QT4Widgets as QT4Widgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import QT4Widgets.WidgetUtils as WidgetUtils
from UI4.Util.LogRecord import LogRecord as LogRecord
from UI4.Widgets.LogRecordTreeView import LogRecordTreeView as LogRecordTreeView
from UI4.Widgets.ToolbarButton import ToolbarButton as ToolbarButton
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class MessagesPopupWindow(PyQt5.QtWidgets.QFrame):
    activeLevelsChanged: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    hideSignal: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    showSignal: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, parent: Incomplete | None = ...) -> None: ...
    def getHighestRecordLevel(self) -> int: ...
    def getTreeView(self): ...
    def hideEvent(self, event: PyQt5.QtGui.QHideEvent): ...
    def on_treeView_activeLevelsChanged(self, activeLevels): ...
    def showEvent(self, event: PyQt5.QtGui.QShowEvent): ...

class MessagesToolbarButton(ToolbarButton):
    class _RecordChanged:
        kAdded: ClassVar[int] = ...
        kNoChange: ClassVar[int] = ...
        kRemoved: ClassVar[int] = ...
    def __init__(self, parent: PyQt5.QtWidgets.QWidget | None) -> None: ...
    def _MessagesToolbarButton__changeIconToHighestPossibleLevel(self, changed: int = ...): ...
    def _MessagesToolbarButton__changeIconToLevel(self, level, changed): ...
    def _MessagesToolbarButton__markActiveLevelsAsRead(self): ...
    def _MessagesToolbarButton__setBlinkState(self, state: bool): ...
    def _MessagesToolbarButton__updateIcon(self): ...
    def on_blinkTimer_timeout(self): ...
    def on_logRecordItemModel_recordAdded(self, level: int): ...
    def on_logRecordItemModel_recordsRemoved(self): ...
    def on_mousePressEvent(self, event: PyQt5.QtGui.QMouseEvent): ...
    def on_popupWindow_activeLevelsChanged(self, activeLevels: set[int]): ...
    def on_popupWindow_hide(self): ...
    def on_popupWindow_show(self): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import CatalogAPI.Client as Client
import PyUtilModule.KatanaFile as KatanaFile
import NodegraphAPI as NodegraphAPI
import Nodes2DAPI as Nodes2DAPI
import PyXmlIO as PyXmlIO
import Utils as Utils
from CatalogAPI.CatalogItem import CatalogItem as CatalogItem, _ClearItemAttrs as _ClearItemAttrs
from _typeshed import Incomplete
from typing import Set, Tuple

RENDER_STATE_CANCELLED: str
RENDER_STATE_COMPLETED: str
RENDER_STATE_ERROR: str
RENDER_STATE_IN_PROGRESS: str
RENDER_STATE_NONE: str

def CreateCatalogItem(itemXML: str = ...): ...
def DeleteCatalogItems(items): ...
def DuplicateCatalogItem(item): ...
def FillDragDataFromItem(mimeData, catalogItem): ...
def FindCatalogItemBySequenceID(sequenceID): ...
def FindUnlockedCatalogItemBySlot(slot: Incomplete | None = ...): ...
def GetCatalogItems(slot: Incomplete | None = ...): ...
def GetCatalogThumbnailWidth() -> int: ...
def GetFirstCatalogItem(slot: Incomplete | None = ...): ...
def GetItemFromDragData(dragData): ...
def GetLastCatalogItem(slot: Incomplete | None = ...): ...
def GetNextCatalogItem(item, slot: Incomplete | None = ...): ...
def GetNumCatalogItems(slot): ...
def GetPreviousCatalogItem(item, slot: Incomplete | None = ...): ...
def MoveCatalogItem(catalogItem, newIndex, slot: Incomplete | None = ...): ...
def MoveCatalogItemToTop(catalogItem): ...
def SetCatalogThumbnailWidth(width: int): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import ConfigurationAPI_cmodule as Configuration
import KatanaResources as KatanaResources
import PyQt5.QtGui
import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
from PyQt5.QtGui import kCopyrightTextColor as kCopyrightTextColor, kDetailTextColor as kDetailTextColor, kVersionTextColor as kVersionTextColor
from _typeshed import Incomplete
from typing import Set, Tuple

class SplashScreen(PyQt5.QtWidgets.QSplashScreen, SplashScreenMixin):
    def __init__(self, parent: PyQt5.QtWidgets.QWidget, pixmap: PyQt5.QtGui.QPixmap) -> None: ...
    def showMessage(self, message: str): ...

class SplashScreenMixin:
    def __init__(self) -> None: ...
    def _addTextGraphicsEffect(self, widget): ...
    def getRightLayout(self) -> PyQt5.QtWidgets.QVBoxLayout: ...
    def setDetailText(self, detailText: str | None): ...
    def setTextSelectable(self, textSelectable: bool): ...

def GetAboutDialogImage(release, detailText: Incomplete | None = ...): ...
def GetDefaultSplashScreenImageFilename() -> str: ...
def GetKatanaBuildDate(dateFormat: str = ...) -> str: ...
def GetSplashScreenImage(release: str, detailText: Incomplete | None = ...) -> PyQt5.QtGui.QImage | None: ...
def GetSplashScreenImageFilename() -> str: ...
def ShowSplashWindow(detailText: Incomplete | None = ...) -> PyQt5.QtWidgets.QSplashScreen | None: ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import CacheManager as CacheManager
import RenderingAPI as RenderingAPI
import Nodes3DAPI.ScenegraphManager as ScenegraphManager
import Utils as Utils
from typing import Set, Tuple

g_flushing_in_progress: bool

def FlushCaches(): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import NodegraphAPI
import PyQt5.QtCore
import PyQt5.QtGui
import PyQt5.QtWidgets
import UI4.Widgets.SceneGraphView.SceneGraphViewIconManager as SceneGraphViewIconManager
import UI4.FormMaster.States as States
import UI4.Widgets.SceneGraphView.Bridge
import UI4.Widgets.SceneGraphView.ItemDelegates.StateItemDelegate
from UI4.Widgets.SceneGraphView.ColumnDataType import RegisterDataType as RegisterDataType
from UI4.Widgets.SceneGraphView.ItemDelegates.BaseItemDelegate import BaseItemDelegate as BaseItemDelegate
from UI4.Widgets.SceneGraphView.ItemDelegates.ParameterItemDelegate import ParameterItemDelegate as ParameterItemDelegate
from UI4.Widgets.SceneGraphView.ItemDelegates.StateItemDelegate import StateItemDelegateMixin as StateItemDelegateMixin
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class MuteItemDelegate(UI4.Widgets.SceneGraphView.ItemDelegates.StateItemDelegate.StateItemDelegateMixin, ParameterItemDelegate):
    FixedColumnWidth: ClassVar[int] = ...
    def __init__(self, bridge: Bridge[UI4.Widgets.SceneGraphView.Bridge.Bridge], treeWidget: PyQt5.QtWidgets.QTreeWidget, parent: Incomplete | None = ...) -> None: ...
    def calculateItemState(self, option: QStyleOptionViewItem, index: PyQt5.QtCore.QModelIndex) -> str: ...
    def initStyleOption(self, option: PyQt5.QtWidgets.QStyleOptionViewItem, index: PyQt5.QtCore.QModelIndex): ...
    def modifyItemState(self, item: PyQt5.QtWidgets.QTreeWidgetItem, index: PyQt5.QtCore.QModelIndex, event: PyQt5.QtGui.QMouseEvent) -> bool: ...
    def setGafferNode(self, gafferNode: NodegraphAPI.Node): ...
    def toolTipEvent(self, index): ...

class SoloItemDelegate(UI4.Widgets.SceneGraphView.ItemDelegates.StateItemDelegate.StateItemDelegateMixin, ParameterItemDelegate):
    FixedColumnWidth: ClassVar[int] = ...
    def __init__(self, bridge: Bridge[UI4.Widgets.SceneGraphView.Bridge.Bridge], treeWidget: PyQt5.QtWidgets.QTreeWidget, parent: Incomplete | None = ...) -> None: ...
    def calculateItemState(self, option: QStyleOptionViewItem, index: PyQt5.QtCore.QModelIndex) -> str: ...
    def initStyleOption(self, option: PyQt5.QtWidgets.QStyleOptionViewItem, index: PyQt5.QtCore.QModelIndex): ...
    def modifyItemState(self, item: PyQt5.QtWidgets.QTreeWidgetItem, index: PyQt5.QtCore.QModelIndex, event: PyQt5.QtGui.QMouseEvent) -> bool: ...
    def setGafferNode(self, gafferNode: NodegraphAPI.Node): ...
    def toolTipEvent(self, index): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from NodegraphAPI.ParameterValueOption import Deferred as Deferred, Immediate as Immediate, ParameterValueOption as ParameterValueOption
from typing import Set, Tuple

AllOptions: list



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import ConfigurationAPI_cmodule as Configuration
import PyQt5.QtCore
import PyXmlIO as PyXmlIO
import QT4FormWidgets
import PyQt5.QtCore as QtCore
from typing import Set, Tuple

class ParamMimeData(PyQt5.QtCore.QMimeData): ...

def GetMimeData(policy: QT4FormWidgets.AbstractValuePolicy) -> PyQt5.QtCore.QMimeData: ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from typing import Any, Set, Tuple

kAssetContextAlembic: str
kAssetContextAttributeFile: str
kAssetContextCastingSheet: str
kAssetContextCatalog: str
kAssetContextFCurveFile: str
kAssetContextFarm: str
kAssetContextGafferThreeRig: str
kAssetContextImage: str
kAssetContextKatanaScene: str
kAssetContextLiveGroup: str
kAssetContextLookFile: str
kAssetContextLookFileMgrSettings: str
kAssetContextMacro: str
kAssetContextScenegraphBookmarks: str
kAssetContextShader: str
kAssetFieldName: str
kAssetFieldVersion: str
kAssetRelationArgsFile: str
kAssetTypeAlembic: str
kAssetTypeAttributeFile: str
kAssetTypeCastingSheet: str
kAssetTypeFCurveFile: str
kAssetTypeGafferThreeRig: str
kAssetTypeImage: str
kAssetTypeKatanaScene: str
kAssetTypeLiveGroup: str
kAssetTypeLookFile: str
kAssetTypeLookFileMgrSettings: str
kAssetTypeMacro: str
kAssetTypeScenegraphBookmarks: str
kAssetTypeShader: str
kFnAssetCreationOptionOutputFormat: str
kFnAssetOutputFormatArchive: str
kFnAssetOutputFormatDirectory: str

class AssetPlugin:
    def __init__(self, *args, **kwargs) -> None: ...
    def buildAssetId(self, fields: dict[str, str], throwOnError: bool = ...) -> str: ...
    def checkPermissions(self, assetId: str, context: dict[str, str], throwOnError: bool = ...) -> bool: ...
    def containsAssetId(self, str: str, throwOnError: bool = ...) -> bool: ...
    def createAssetAndPath(self, txn: AssetTransaction, assetType: str, assetFields: dict[str, str], args: dict[str, str], createDirectory: bool = ..., throwOnError: bool = ...) -> str: ...
    def createTransaction(self, throwOnError: bool = ...) -> AssetTransaction: ...
    def getAssetAttributes(self, assetId: str, scope: str, throwOnError: bool = ...) -> dict[str, str]: ...
    def getAssetDisplayName(self, assetId: str, throwOnError: bool = ...) -> str: ...
    def getAssetFields(self, assetId: str, includeDefaults: bool, throwOnError: bool = ...) -> dict[str, str]: ...
    def getAssetIdForScope(self, assetId: str, scope: str, throwOnError: bool = ...) -> str: ...
    def getAssetVersions(self, assetId: str, throwOnError: bool = ...) -> tuple: ...
    def getRelatedAssetId(self, assetId: str, relation: str, throwOnError: bool = ...) -> str: ...
    def getUniqueScenegraphLocationFromAssetId(self, assetId: str, includeVersion: bool, throwOnError: bool = ...) -> str: ...
    def isAssetId(self, assetStr: str, throwOnError: bool = ...) -> bool: ...
    def postCreateAsset(self, txn: AssetTransaction, assetType: str, assetFields: dict[str, str], args: dict[str, str], throwOnError: bool = ...) -> str: ...
    def reset(self, throwOnError: bool = ...) -> None: ...
    def resolveAllAssets(self, str: str, throwOnError: bool = ...) -> str: ...
    def resolveAsset(self, assetId: str, throwOnError: bool = ...) -> str: ...
    def resolveAssetVersion(self, assetId: str, versionStr: str = ..., throwOnError: bool = ...) -> str: ...
    def resolvePath(self, assetId: str, frame: int, throwOnError: bool = ...) -> str: ...
    def runAssetPluginCommand(self, assetId: str, command: str, commandArgs: dict[str, str], throwOnError: bool = ...) -> bool: ...
    def setAssetAttributes(self, assetId: str, scope: str, attrs: dict[str, str], throwOnError: bool = ...) -> None: ...
    def __hash__(self) -> int: ...

class AssetTransaction:
    def __init__(self, *args, **kwargs) -> None: ...
    def commit(self, throwOnError: bool = ...) -> bool: ...
    def __hash__(self) -> int: ...

class FileSequence:
    def __init__(self, *args, **kwargs) -> None: ...
    def getAsString(self, throwOnError: bool = ...) -> str: ...
    def getDirectory(self, throwOnError: bool = ...) -> str: ...
    def getFirstFrame(self, throwOnError: bool = ...) -> int: ...
    def getFrameList(self, throwOnError: bool = ...) -> list[int]: ...
    def getLastFrame(self, throwOnError: bool = ...) -> int: ...
    def getNearestFrames(self, frame: int, throwOnError: bool = ...) -> tuple: ...
    def getPadding(self, throwOnError: bool = ...) -> int: ...
    def getPrefix(self, throwOnError: bool = ...) -> str: ...
    def getResolvedPath(self, frame: int, throwOnError: bool = ...) -> str: ...
    def getSuffix(self, throwOnError: bool = ...) -> str: ...
    def hasFrame(self, frame: int, throwOnError: bool = ...) -> bool: ...
    def hasFrameSet(self, throwOnError: bool = ...) -> bool: ...
    def __hash__(self) -> int: ...

class FileSequencePlugin:
    def __init__(self, *args, **kwargs) -> None: ...
    def buildFileSequenceString(self, prefix: str, suffix: str, padding: int = ..., throwOnError: bool = ...) -> str: ...
    def findSequence(self, fileListObj: list[str], throwOnError: bool = ...) -> tuple: ...
    def findSequenceOnDisk(self, path: str, recursive: bool, includeHidden: bool, throwOnError: bool = ...) -> tuple: ...
    def getFileSequence(self, fileSequenceStr: str, throwOnError: bool = ...) -> FileSequence: ...
    def isFileSequence(self, fileSequenceStr: str, throwOnError: bool = ...) -> bool: ...
    def __hash__(self) -> int: ...

def GetAssetPlugin(pluginName: str) -> Any: ...
def GetAssetPluginNames() -> list[str]: ...
def GetDefaultAssetPlugin() -> Any: ...
def GetDefaultAssetPluginName() -> str: ...
def GetDefaultFileSequencePlugin() -> Any: ...
def GetDefaultFileSequencePluginName() -> str: ...
def GetFileSequencePlugin(pluginName: str) -> Any: ...
def GetFileSequencePluginNames() -> list[str]: ...
def ResetAllAssetAPIPlugins() -> None: ...
def SetDefaultAssetPluginName(pluginName: str) -> None: ...
def SetDefaultFileSequencePluginName(pluginName: str) -> None: ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import ConfigurationAPI_cmodule as Configuration
import Utils as Utils
from Utils.Decorators import deprecated as deprecated
from typing import Set, Tuple

def GetExternalEditor(): ...
def GetExternalEditorName(): ...
def GetKatanaTempfile(prefix, suffix, maxInt: int = ...): ...
def OpenFileInExternalEditor(filename): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import Naming as Naming
import NodegraphAPI
import PyQt5.QtCore
import QT4FormWidgets as QT4FormWidgets
import QT4Widgets.SortableTreeWidget
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import UI4 as UI4
import Naming as UniqueName
import Utils as Utils
from QT4FormWidgets.FormWidget import FormWidget
from UI4.Util.UndoGrouping import UndoGrouping as UndoGrouping
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class HierarchyCreateFormWidget(FormWidget):
    mousePressEventSignal: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, parent, policy, factory) -> None: ...
    def _HierarchyCreateFormWidget__aboutToDragCallback(self, items, dragObject): ...
    def _HierarchyCreateFormWidget__actionMenuAboutToShow(self): ...
    def _HierarchyCreateFormWidget__addChildLocation(self): ...
    def _HierarchyCreateFormWidget__buildLocation(self, entry, parent, openState, selectedState): ...
    def _HierarchyCreateFormWidget__callLocationRenamedCallback(self, path, newPath): ...
    def _HierarchyCreateFormWidget__dragMoveEventCallback(self, event, parent, index, callbackRecord): ...
    def _HierarchyCreateFormWidget__dropEventCallback(self, event, parent, index): ...
    def _HierarchyCreateFormWidget__fillMenu(self, menu): ...
    def _HierarchyCreateFormWidget__itemEdited(self, item, column, value: Incomplete | None = ...): ...
    def _HierarchyCreateFormWidget__itemExpanded(self, item): ...
    def _HierarchyCreateFormWidget__keyPressEvent(self, event): ...
    def _HierarchyCreateFormWidget__parameterEvents(self, args): ...
    def _HierarchyCreateFormWidget__reduceDragItems(self): ...
    def _HierarchyCreateFormWidget__reduceSelection(self, selectedItems: Incomplete | None = ...): ...
    def _HierarchyCreateFormWidget__selectionChanged(self): ...
    def _HierarchyCreateFormWidget__setupEventHandlers(self, active): ...
    def _HierarchyCreateFormWidget__treeMousePressEvent(self, event): ...
    def _HierarchyCreateFormWidget__updateList(self, startingAt: Incomplete | None = ...): ...
    def _buildTopAreaLayout(self, layout): ...
    def _freeze(self): ...
    def _thaw(self): ...
    def addPreselectedPaths(self, path): ...
    def getActiveItems(self): ...
    def getDelegate(self): ...
    def getNode(self) -> NodegraphAPI.Node: ...
    def getToolbar(self): ...
    def getToolbarCenterLayout(self): ...
    def getToolbarLeftLayout(self): ...
    def getToolbarRightLayout(self): ...
    def getTree(self): ...
    def isItemColumnEditable(self, item, column): ...
    def setDelegate(self, delegate): ...
    def setLocationRenamedCallback(self, callback): ...
    def updateList(self): ...

class HierarchyCreateListItemDelegate(QT4Widgets.SortableTreeWidget.SortableTreeWidgetItemDelegate):
    itemEdited: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def createEditor(self, parent, option, index): ...
    def getFormWidgetDelegate(self): ...
    def getFormWidgetParent(self): ...
    def paint(self, painter, option, index): ...
    def setModelData(self, editor, model, index): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import QT4Panels.DragTabs as DragTabs
import PyQt5.QtCore
import PyQt5.QtWidgets
import QT4Widgets as QT4Widgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
from typing import ClassVar, Set, Tuple

class PanelFrame(PyQt5.QtWidgets.QTabWidget):
    frameMaximized: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, parent) -> None: ...
    def addTab(self, widget, label): ...
    def close(self): ...
    def closeEvent(self, event): ...
    def doTabDoubleClick(self, index): ...
    def doTabRightMouse(self, index): ...
    def doTabStartDrag(self, index): ...
    def event(self, event): ...
    def getDragRect(self): ...
    def getFrameMaximized(self): ...
    def getMinSize(self): ...
    def getPhysRect(self, margin: int = ...): ...
    def getRealRect(self): ...
    def insertTab(self, index, widget, label): ...
    def keyPressEvent(self, event): ...
    def setDragRect(self, coordinates): ...
    def setFrameMaximized(self, state): ...
    def setPhysRect(self, coordinates): ...
    def setRealRect(self, coordinates): ...
    def __bool__(self) -> bool: ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import UI4.Widgets.SceneGraphView.SceneGraphViewIconManager as SceneGraphViewIconManager
import UI4.Util.ScenegraphIconManager as ScenegraphIconManager
import typing
from UI4.Widgets.SceneGraphView.SceneGraphViewColumn import SceneGraphColumnSet as SceneGraphColumnSet
from _typeshed import Incomplete
from typing import Set, Tuple

class ColumnManager:
    def __init__(self, columnChangedCallback: typing.Callable | None, columnPresetManager: Incomplete | None = ...) -> None: ...
    def addColumn(self, columnName): ...
    def addColumnSet(self, columnSetName): ...
    def applyColumnVisibilitySettings(self, columnVisibility): ...
    def applyColumnWidthsSettings(self, columnWidths): ...
    def getColumnAttributeName(self, columnIndex: int, visibleOnly: bool = ...) -> str: ...
    def getColumnAttributeNames(self, columnIndex: int, visibleOnly: bool = ...) -> list[str]: ...
    def getColumnByIndex(self, columnIndex, visibleOnly: bool = ...): ...
    def getColumnByName(self, columnName): ...
    def getColumnCount(self, visibleOnly: bool = ...): ...
    def getColumnTitleText(self, columnIndex, visibleOnly: bool = ...): ...
    def getColumnTitles(self, visibleOnly: bool = ...): ...
    def getColumnVisibilitySettings(self): ...
    def getColumnWidths(self, visibleOnly: bool = ...): ...
    def getColumnWidthsSettings(self): ...
    def getDataType(self, columnIndex: int) -> int: ...
    def getRootColumnSet(self): ...
    def hideColumnSet(self, columnSetName): ...
    def isEditable(self, columnIndex, visibleOnly: bool = ...): ...
    def isLocationNameColumn(self, columnIndex, visibleOnly: bool = ...): ...
    def moveColumn(self, columnIndex, newColumnIndex, visibleOnly: bool = ...): ...
    def setColumnChangedCallback(self, callback): ...
    def setColumnSetVisible(self, columnSetName, visible): ...
    def showColumnSet(self, columnSetName): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtWidgets
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
from typing import Set, Tuple

class VerticalDivider(PyQt5.QtWidgets.QFrame):
    def __init__(self, *args) -> None: ...
    def paintEvent(self, event): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import Callbacks as Callbacks
import KatanaResources as KatanaResources
import PyQt5.QtCore
import PyQt5.QtGui
import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import UI4.App.TimelineWidget as TimelineWidget
import UI4 as UI4
import Utils as Utils
from Utils.Decorators import deprecated as deprecated
from typing import Set, Tuple

class TabWithTimeline(PyQt5.QtWidgets.QWidget):
    def __init__(self, widget: PyQt5.QtWidgets.QWidget) -> None: ...
    def closeEvent(self, event: PyQt5.QtGui.QCloseEvent): ...
    def getPanel(self): ...
    def getTabTitle(self) -> str: ...
    def getWidget(self) -> PyQt5.QtWidgets.QWidget: ...
    def isTimelineShown(self) -> bool: ...
    def setSizeHint(self, sizeHint: PyQt5.QtCore.QSize): ...
    def showTimeline(self, show: bool): ...
    def sizeHint(self) -> PyQt5.QtCore.QSize: ...

def ApplySettings(widget: PyQt5.QtWidgets.QFrame, settings: dict): ...
def CloseUnusedTabs(): ...
def CreateTab(tabTypeName: str, parent: PyQt5.QtWidgets.QWidget) -> TabWithTimeline: ...
def FindTopTab(tabTypeName: str, alsoRaise: bool = ...) -> PyQt5.QtWidgets.QWidget | None: ...
def GetAllTabs() -> list[PyQt5.QtWidgets.QWidget]: ...
def GetAvailableTabTypeNames() -> list[str]: ...
def GetSettings(widget: PyQt5.QtWidgets.QFrame) -> dict: ...
def GetTabIcon(tabTypeName: str) -> PyQt5.QtGui.QIcon | None: ...
def GetTabMenuItemIcon(tabTypeName: str) -> PyQt5.QtGui.QIcon | None: ...
def GetTabPluginPath(tabTypeName) -> str: ...
def GetTabPluginSearchPaths() -> list[str]: ...
def GetTabTitle(tabTypeName: str) -> str: ...
def GetTabType(widget): ...
def GetTabTypeName(widget: TabWithTimeline | PyQt5.QtWidgets.QWidget) -> str: ...
def GetTabWidgetIndex(widget: PyQt5.QtWidgets.QWidget) -> tuple: ...
def GetTabsByType(tabTypeName: str) -> list[PyQt5.QtWidgets.QWidget]: ...
def IsTabPersistent(name): ...
def IsTabTypePersistent(tabTypeName: str) -> bool: ...
def LoadTabPlugins(tabPluginSearchPaths: list[str]) -> set[str]: ...
def LoadedTabs(): ...
def RaiseTab(widget: PyQt5.QtWidgets.QWidget): ...
def TabPluginPaths(): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from . import AttributeEditorDelegate as AttributeEditorDelegate, FaceSetCreateDelegate as FaceSetCreateDelegate, FileIn as FileIn, GroupStackDelegate as GroupStackDelegate, IsolateDelegate as IsolateDelegate, MaterialAssignDelegate as MaterialAssignDelegate, MaterialDelegate as MaterialDelegate, MaterialStackDelegate as MaterialStackDelegate, PruneDelegate as PruneDelegate, RendererProceduralAssignDelegate as RendererProceduralAssignDelegate, Transform3D as Transform3D
from typing import Set, Tuple



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from typing import Set, Tuple

class ScrollAreaMemory:
    def __init__(self, target) -> None: ...
    def __del__(self) -> None: ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtCore
import PyQt5.QtGui
import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import typing
from _typeshed import Incomplete
from typing import Set, Tuple

class CaseInsensitiveStringListModel(PyQt5.QtCore.QStringListModel):
    def __init__(self, parent: Incomplete | None = ..., *args) -> None: ...
    def setStringList(self, stringList): ...

class PythonWidgetIntrospector:
    def __init__(self, parent, executionEnvironment: Incomplete | None = ...) -> None: ...
    def _PythonWidgetIntrospector__findMatchingObjects(self, tokenFragments: list[str]) -> dict: ...
    def _PythonWidgetIntrospector__getFunctionArgsString(self, module: Module, attributeName: str, explicitAttr: Incomplete | None = ...): ...
    def _PythonWidgetIntrospector__onCompleterHighlighted(self, completionText: str): ...
    def _PythonWidgetIntrospector__setCompletionPrefix(self, prefix: str): ...
    def _PythonWidgetIntrospector__setTooltipPalette(self): ...
    def addCommandWidget(self, widget): ...
    def addFunctionCallback(self, obj: object, functionName: str, enterCallback: typing.Optional[typing.Callable] = ..., exitCallback: typing.Optional[typing.Callable] = ...): ...
    def addTooltipWidget(self, widget): ...
    def endCompletion(self): ...
    def getCurrentToken(self, widget: QWidget, textCursor: Incomplete | None = ...): ...
    def getPossibleCompletions(self, token: str): ...
    def getStringToLastDelimiter(self, text: str, delimiters: list = ...) -> str: ...
    def getStringToNextDelimiter(self, text: str, delimiters: list = ...) -> str: ...
    def insertCompleterSelection(self, selectedText: str): ...
    def onKeyPressEvent(self, widget: PyQt5.QtWidgets.QWidget, keyEvent: PyQt5.QtGui.QKeyEvent) -> bool: ...
    def onKeyPressEventExit(self, widget: PyQt5.QtWidgets.QWidget, keyEvent: PyQt5.QtGui.QKeyEvent): ...
    def onMouseMove(self, widget: QWidget, mouseEvent): ...
    def removeTooltipWidget(self, widget): ...
    def setExecutionEnvironment(self, env: dict): ...
    def setUseAutoCompletionPopup(self, useAutoCompletionPopup): ...
    def updateCompletionsWithToken(self, widget: QWidget, token: str): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import ConfigurationAPI_cmodule as Configuration
import PyQt5.QtCore
import PyQt5.QtCore as QtCore
import typing
from UI4.Util.RecordItemModel import RecordItemModel as RecordItemModel
from _typeshed import Incomplete
from typing import Set, Tuple

gLogRecordItemModel: None

class LogRecordItemModel(RecordItemModel):
    class SortFilterProxyModel(PyQt5.QtCore.QSortFilterProxyModel):
        def __init__(self, parent: Incomplete | None = ...) -> None: ...
        def filterAcceptsRow(self, sourceRow: int, sourceParentIndex: PyQt5.QtCore.QModelIndex) -> bool: ...
        def getActiveLevels(self) -> set[int]: ...
        def isLevelFilterEnabled(self, level: int) -> bool: ...
        def lessThan(self, leftIndex: PyQt5.QtCore.QModelIndex, rightIndex: PyQt5.QtCore.QModelIndex) -> bool: ...
        def setActiveLevels(self, levels: typing.Iterable[int]): ...
        def setLevelFilter(self, level: int, enabled: bool = ...): ...
        def sort(self, column, order: PyQt5.QtCore.Qt.SortOrder = ...): ...
    def __init__(self) -> None: ...
    def addRecord(self, record: Record) -> bool: ...
    def data(self, modelIndex: PyQt5.QtCore.QModelIndex, role: PyQt5.QtCore.Qt.ItemDataRole = ...) -> PyQt5.QtCore.QVariant: ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from . import AboutKatana as AboutKatana, AutoSave as AutoSave, Hotkeys as Hotkeys, Icon as Icon, KeyboardShortcutManager as KeyboardShortcutManager, Layouts as Layouts, MainMenu as MainMenu, MainWindow as MainWindow, Preferences as Preferences, RecentFiles as RecentFiles, Splash as Splash, Tabs as Tabs, TimelineWidget as TimelineWidget
from typing import Set, Tuple



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import QT4FormWidgets.FWidget as FWidget
import QT4FormWidgets.PaintingUtils as PaintingUtils
import PyQt5.QtCore
import PyQt5.QtGui
import PyQt5.QtWidgets
import QT4FormWidgets.FWidget
import QT4Widgets as QT4Widgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import ResourceFiles as ResourceFiles
from ResourceFiles.IconManager import ResourceManager as ResourceManager
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class HelpButton(PyQt5.QtWidgets.QPushButton):
    _HelpButton__pixmaps: ClassVar[dict] = ...
    aboutToShow: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, parent, helpName: str = ..., helpText: str = ...) -> None: ...
    def _displayHelpDialog(self): ...
    def contextMenuEvent(self, event): ...
    def getHelpText(self): ...
    def mousePressEvent(self, event): ...
    def setHelpText(self, helpText): ...

class HelpDialog(PyQt5.QtWidgets.QFrame):
    class DragLabel(PyQt5.QtWidgets.QLabel):
        def __init__(self, label, parent) -> None: ...
        def mouseMoveEvent(self, ev): ...
        def mousePressEvent(self, ev): ...
        def mouseReleaseEvent(self, ev): ...
    _HelpDialog__instances: ClassVar[set] = ...
    _HelpDialog__pixmaps: ClassVar[dict] = ...
    def __init__(self, helpText, parent: Incomplete | None = ..., caption: str = ...) -> None: ...
    def _HelpDialog__buildChildren(self, helpText): ...
    def _HelpDialog__linkClicked_callback(self, url: str): ...
    def closeEvent(self, event): ...
    def positionAtGlobalPoint(self, point, screenID: Incomplete | None = ...): ...
    def showEvent(self, event): ...
    def tearOff(self): ...

class HelpFWidget(QT4FormWidgets.FWidget.FPixmap):
    _HelpFWidget__pixmaps: ClassVar[dict] = ...
    aboutToShow: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, parent) -> None: ...
    def _HelpFWidget__loadResources(self): ...
    def _displayHelpDialog(self): ...
    def contextMenuEvent(self, event): ...
    def getHelpName(self): ...
    def getHelpText(self): ...
    def getHelpType(self): ...
    def isHelpEnabled(self): ...
    def mousePressEvent(self, event): ...
    def updateAppearance(self): ...

class InputComboBox(PyQt5.QtWidgets.QComboBox):
    EMITS_CUSTOM_FOCUS_EVENTS: ClassVar[bool] = ...
    gotFocus: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    itemChosen: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    lostFocus: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, *args) -> None: ...
    def _InputComboBox__activated(self, index: Incomplete | None = ...): ...
    def _InputComboBox__lineEditGotFocus(self): ...
    def _InputComboBox__lineEditLostFocus(self): ...
    def keyPressEvent(self, event): ...
    def mousePressEvent(self, event): ...
    def paintEvent(self, event: PyQt5.QtGui.QPaintEvent): ...
    def setMinimal(self, minimal: bool): ...
    def setReadOnly(self, state): ...
    def setText(self, text): ...
    def showPopup(self): ...
    def text(self, index: int = ...): ...
    def wheelEvent(self, event): ...

class InputLineEdit(PyQt5.QtWidgets.QLineEdit):
    EMITS_CUSTOM_FOCUS_EVENTS: ClassVar[bool] = ...
    _InputLineEdit__selectAllOnFocus: ClassVar[bool] = ...
    _InputLineEdit__singleDigitScrollingEnabled: ClassVar[bool] = ...
    decrement: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    dragEnterEventSignal: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    dragStarted: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    dropEventSignal: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    gotFocus: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    increment: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    lostFocus: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    scrollDigitDown: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    scrollDigitUp: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, *args) -> None: ...
    @classmethod
    def _InputLineEdit__findFirstLeadingZeroScrollBlockIndex(cls, text: str, index: int) -> int: ...
    @classmethod
    def _InputLineEdit__findLeadingZeroBlock(cls, text: str, index: int) -> int: ...
    @classmethod
    def _InputLineEdit__findScrollBlockHexIndex(cls, text: str, index: int) -> int: ...
    @classmethod
    def _InputLineEdit__findScrollStartIndex(cls, text: str, index: int) -> int: ...
    @classmethod
    def _InputLineEdit__flipScrollDigitSign(cls, text: str, firstZeroIndex: int, index: int, isHex: bool) -> tuple[str, int]: ...
    @classmethod
    def _InputLineEdit__isScrollBlockHex(cls, text: str, index: int) -> bool: ...
    @classmethod
    def _InputLineEdit__isScrollBlockNegative(cls, text: str, index: int) -> bool: ...
    @classmethod
    def _InputLineEdit__prepareScrollTextAndIndex(cls, text: str, index: int, isInt: bool) -> tuple[str, int]: ...
    @classmethod
    def _InputLineEdit__removeLeadingZeroesFromBlock(cls, text: str, index: int) -> tuple[str, int]: ...
    def _InputLineEdit__scrollCursorPosFromSelection(self) -> int: ...
    def _InputLineEdit__scrollDigitCommon(self, text, cursorPos, scrollFunction, invScrollFunction) -> tuple[str, int]: ...
    @classmethod
    def _InputLineEdit__scrollDigitDown(cls, text: str, index: int, isInt: bool) -> tuple[str, int]: ...
    def _InputLineEdit__scrollDigitDownCB(self): ...
    @classmethod
    def _InputLineEdit__scrollDigitUp(cls, text: str, index: int, isInt: bool) -> tuple[str, int]: ...
    def _InputLineEdit__scrollDigitUpCB(self): ...
    def _InputLineEdit__startDrag(self): ...
    def contextMenuEvent(self, event): ...
    def customEvent(self, event): ...
    def dragEnterEvent(self, event): ...
    def dropEvent(self, event): ...
    def focusInEvent(self, event): ...
    def focusOutEvent(self, event): ...
    def hideEvent(self, event): ...
    def keyPressEvent(self, event): ...
    def mouseMoveEvent(self, event): ...
    def mousePressEvent(self, event): ...
    def mouseReleaseEvent(self, event): ...
    def setFloatScrollingEnabled(self, value: bool): ...
    def setReadOnly(self, state): ...
    @classmethod
    def setSelectAllOnFocus(cls, selectAllOnFocus): ...
    @classmethod
    def setSingleDigitScrolling(cls, value: bool): ...
    def setText(self, text): ...
    def sizeHint(self): ...
    def wheelEvent(self, event): ...

class InputTextEdit(PyQt5.QtWidgets.QTextEdit):
    EMITS_CUSTOM_FOCUS_EVENTS: ClassVar[bool] = ...
    contextMenuEventSignal: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    enterPressed: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    gotFocus: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    lostFocus: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, *args) -> None: ...
    def contextMenuEvent(self, event): ...
    def focusInEvent(self, event): ...
    def focusOutEvent(self, event): ...
    def hideEvent(self, event): ...
    def keyPressEvent(self, event): ...
    def setReadOnly(self, state): ...
    def sizeHint(self): ...
    def text(self): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtWidgets as QtWidgets
from _typeshed import Incomplete
from typing import Set, Tuple

class SwitchingBoxLayout(PyQt5.QtWidgets.QLayout):
    def __init__(self) -> None: ...
    def addItem(self, item): ...
    def addLayout(self, layout): ...
    def count(self): ...
    def expandingDirections(self): ...
    def hasHeightForWidth(self): ...
    def heightForWidth(self, w): ...
    def itemAt(self, index): ...
    def minimumSize(self): ...
    def setGeometry(self, geometry: Incomplete | None = ...): ...
    def setSpacing(self, spacing, direction: Incomplete | None = ...): ...
    def sizeHint(self): ...
    def spacing(self, direction: Incomplete | None = ...): ...
    def takeAt(self, index): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import AssetAPI as AssetAPI
import MediaCacheHandler as MediaCacheHandler
import UI4.Widgets.MessageBox as MessageBox
import NodegraphAPI as NodegraphAPI
import PyQt5.QtCore
import PyQt5.QtCore as QtCore
import Utils as Utils
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class CancelledException(Exception): ...

class MediaCacheCopyThread(PyQt5.QtCore.QThread):
    elementDeleted: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    elementProgress: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    fileProgress: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, elements, elementsSafeForDeletion) -> None: ...
    def _MediaCacheCopyThread__deletionCB(self): ...
    def _MediaCacheCopyThread__elementProgressCB(self, elementName, i, total): ...
    def _MediaCacheCopyThread__fileProgressCB(self, fileName, i, total): ...
    def cancel(self): ...
    def getException(self): ...
    def run(self): ...
    def wasCancelled(self): ...
    def wasError(self): ...

class MediaCacheTransfer:
    def __init__(self, elementSet) -> None: ...
    def _MediaCacheTransfer__checkAspera(self): ...
    def _MediaCacheTransfer__copyFinished(self): ...
    def _MediaCacheTransfer__doCopying(self, postAsperaElements): ...
    def _MediaCacheTransfer__elementDeletedCB(self, elementName): ...
    def _MediaCacheTransfer__elementProgressCB(self, elementName, elementsCompleted, totalElements): ...
    def _MediaCacheTransfer__fileProgressCB(self, fileName, filesCompleted, totalFiles): ...
    def _MediaCacheTransfer__sendEvent(self, eventName, **kwargs): ...
    def cancel(self): ...
    def getElements(self): ...
    def getId(self): ...
    def start(self): ...

def CancelMediaCacheRefresh(id): ...
def DoesGraphHaveCacheableNodes(nodes: Incomplete | None = ...): ...
def GetFileElements(nodes: Incomplete | None = ..., t: Incomplete | None = ...): ...
def StartMediaCacheRefresh(elements: Incomplete | None = ..., nodes: Incomplete | None = ..., t: Incomplete | None = ...): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtCore
import PyQt5.QtGui
import PyQt5.QtWidgets
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
from typing import Set, Tuple

class DropdownArrowButton(PyQt5.QtWidgets.QPushButton):
    def __init__(self, height) -> None: ...
    def enterEvent(self, event: PyQt5.QtCore.QEvent): ...
    def leaveEvent(self, event: PyQt5.QtCore.QEvent): ...
    def paintEvent(self, event: PyQt5.QtGui.QPaintEvent): ...
    def setDropdownEnabled(self, enabled: bool): ...
    def setRectangularFixedSize(self, height: int | None): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyFnAttribute as FnAttribute
import NodegraphAPI as NodegraphAPI
from Nodes3DAPI.Constraints.BaseConstraint import BaseConstraint as BaseConstraint
from typing import Set, Tuple

_ParamHints: dict
_Parameter_XML: str

class AimConstraint(BaseConstraint):
    def __init__(self) -> None: ...
    def addParameterHints(self, attrName, inputDict): ...
    def getAllowMissingTargets(self, time): ...
    def getBasePath(self, time): ...
    def getConstraintArguments(self, time): ...
    def getConstraintType(self, time): ...
    def getRequireTargetBounds(self, time): ...
    def getTargetPaths(self, time): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyFnAttribute
from typing import Set, Tuple

kVirtualCameraSceneGraphLocation: str

def GetVirtualCameraAttributes() -> PyFnAttribute.GroupAttribute | None: ...
def SetVirtualCameraAttributes(attributes: PyFnAttribute.GroupAttribute | None): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyFnAttribute as FnAttribute
import PyFnGeolib as FnGeolib
import Nodes3DAPI.Node3D as Node3D
import NodegraphAPI as NodegraphAPI
import NodegraphAPI_cmodule
import Nodes3DAPI.Node3D_geolib3
import Utils as Utils
from Nodes3DAPI.Node3D_geolib3 import NodeGeolib3 as NodeGeolib3
from typing import ClassVar, Set, Tuple

_ExtraHints: dict

class BaseShadingNodeSubnet(Nodes3DAPI.Node3D_geolib3.NodeGeolib3):
    ADD_EXCEPTION_TEXT: ClassVar[str] = ...
    def __init__(self) -> None: ...
    def _BaseShadingNodeSubnet__buildOpArgs(self, graphState: NodegraphAPI.GraphState): ...
    def _BaseShadingNodeSubnet__getPublicInterfaceParameters(self, frameTime): ...
    def _getOp(self, port: NodegraphAPI.Port, graphState: NodegraphAPI.GraphState, visitedState, transaction): ...
    def addExposedParameters(self): ...
    @classmethod
    def addGroupParametersToList(cls, node: NodegraphAPI.Node, result): ...
    def addParameterHints(self, attrName, inputDict): ...
    def addPublicInterfaceParameter(self, param, checkForDuplicate: bool = ...): ...
    @classmethod
    def getGroupParametersAndPublicInterfaceOrders(cls, nodeList): ...
    def getPublicInterfaceOrder(self, frameTime): ...
    def getPublicInterfaceParameters(self, frameTime): ...

class ShadingNodeSubnet(NodegraphAPI_cmodule.PythonGroupNode, BaseShadingNodeSubnet):
    def __init__(self) -> None: ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtWidgets
import QT4FormWidgets as QT4FormWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import UI4.Widgets.SortablePanel as SortablePanel
import UI4 as UI4
import UI4.Widgets.SortablePanel
from _typeshed import Incomplete
from typing import Set, Tuple

class BooleanPanel(UI4.Widgets.SortablePanel.SortablePanelBase):
    def __init__(self, parent, entry, policy: Incomplete | None = ..., includeGroupsInMenu: bool = ...) -> None: ...
    def getChildWidget(self): ...
    def getEntry(self): ...

class ComparisonPanel(UI4.Widgets.SortablePanel.SortablePanelBase):
    def __init__(self, parent, entry, policy: Incomplete | None = ..., includeGroupsInMenu: bool = ...) -> None: ...
    def getEntry(self): ...

class ConditionalHintEditor(UI4.Widgets.SortablePanel.SortablePanelFormWidget):
    def __init__(self, parent, policy, factory, rootEntry, includeGroupsInMenu: bool = ...) -> None: ...
    def _ConditionalHintEditor__addCondition(self, action): ...
    def _ConditionalHintEditor__buildPanels(self, entry): ...
    def _buildControlWidget(self, hbox): ...
    def buildAddMenu(self, menu): ...
    def getEntry(self): ...
    def getOpWidget(self): ...

class ConditionalHintEditorDialog(PyQt5.QtWidgets.QDialog):
    def __init__(self, inputHints, inputPolicy, hintType, includeGroupsInMenu: bool = ...) -> None: ...
    def _ConditionalHintEditorDialog__getKey(self): ...
    def getResult(self): ...

class RelativePolicyPathSelectorWidget(PyQt5.QtWidgets.QFrame):
    def __init__(self, parent, policy: Incomplete | None = ..., includeGroupsInMenu: bool = ...) -> None: ...
    def _RelativePolicyPathSelectorWidget__pathPopupAboutToShow(self): ...
    def _RelativePolicyPathSelectorWidget__pathPopupItemChosen(self, text, meta): ...
    def _RelativePolicyPathSelectorWidget__showOnlyPeersCallback(self, state, name, meta): ...
    def _RelativePolicyPathSelectorWidget__walkPolicy(self, policy): ...
    def setText(self, value): ...
    def text(self): ...

def GetBooleanOperatorNames(): ...
def GetComparisonOperatorNames(): ...
def GetConditionalNamesFromHintDict(hintDict, hintType): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import UI4.Widgets.MessageBox as MessageBox
import NodegraphAPI as NodegraphAPI
import PyQt5.QtCore
import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import UI4.Widgets.SortablePanel
from QT4Widgets.MenuButton import MenuButton as MenuButton
from UI4.Widgets.SortablePanel import SortablePanelBase as SortablePanelBase, SortablePanelFormWidget as SortablePanelFormWidget
from typing import ClassVar, Set, Tuple

class ForkVariablesEditor(UI4.Widgets.SortablePanel.SortablePanelFormWidget):
    def __init__(self, parent, policy, factory) -> None: ...
    def _ForkVariablesEditor__addNumberVariable(self): ...
    def _ForkVariablesEditor__addStringVariable(self): ...
    def _ForkVariablesEditor__getNewVariableName(self, typeid): ...
    def _ForkVariablesEditor__getNode(self): ...
    def addOutput(self): ...
    def buildAddMenu(self, menu): ...
    def deletePanel(self, index): ...
    def deleteVariable(self, name): ...
    def panelDeleted(self, index): ...
    def panelReordered(self, oldPos, newPos): ...
    def renameVariable(self, oldName, newName): ...
    def updatePanels(self): ...

class OutputVariablePanel(UI4.Widgets.SortablePanel.SortablePanelBase):
    class _OutputVariablePanel__VariableWidget(PyQt5.QtWidgets.QFrame):
        variableDelete: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
        variableRename: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
        def __init__(self, parent, policy, factory) -> None: ...
        def _VariableWidget__copyExpression(self): ...
        def _VariableWidget__deleteCallback(self): ...
        def _VariableWidget__renameVariable(self): ...
        def getWidgetLabelWidth(self): ...
        def setWidgetLabelWidth(self, width): ...
    def __init__(self, parent, name, policy, factory) -> None: ...
    def _OutputVariablePanel__deleteVariable(self, name): ...
    def _OutputVariablePanel__renameVariable(self, name): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import QT4FormWidgets as QT4FormWidgets
import QT4FormWidgets.PythonValuePolicy
from _typeshed import Incomplete
from typing import Set, Tuple

def CreateColorPolicy(name: str = ..., hasAlpha: bool = ..., enableFilmlook: Incomplete | None = ..., restrictComponents: Incomplete | None = ..., color: tuple = ..., readOnly: bool = ...) -> QT4FormWidgets.PythonValuePolicy: ...
def DoesColorPolicyEnableFilmlook(policy: QT4FormWidgets.PythonValuePolicy, default: Incomplete | None = ...) -> bool: ...
def DoesColorPolicyEnableNoFilmlookColorSpace(policy: QT4FormWidgets.PythonValuePolicy, default: Incomplete | None = ...) -> bool: ...
def DoesColorPolicyHaveAlpha(policy: QT4FormWidgets.PythonValuePolicy) -> bool: ...
def DoesColorPolicyRestrictComponents(policy: QT4FormWidgets.PythonValuePolicy, default: Incomplete | None = ...) -> bool: ...
def GetColorPolicyChildren(policy: QT4FormWidgets.PythonValuePolicy | None) -> list[QT4FormWidgets.PythonValuePolicy._NumberPythonPolicy]: ...
def GetColorPolicyRGBA(policy: QT4FormWidgets.PythonValuePolicy | None) -> None: ...
def GetDefaultColorComponentTab(policy: QT4FormWidgets.PythonValuePolicy | None) -> str: ...
def SetColorPolicyEnableFilmlook(policy: QT4FormWidgets.PythonValuePolicy, enableFilmlook: bool): ...
def SetColorPolicyEnableFilmlookDefault(default: bool): ...
def SetColorPolicyEnableNoFilmlookColorSpaceDefault(default: bool): ...
def SetColorPolicyRGBA(policy: QT4FormWidgets.PythonValuePolicy, color: tuple[float, ...], final: bool = ...) -> bool: ...
def SetColorPolicyRestrictComponents(policy: QT4FormWidgets.PythonValuePolicy, restrictComponents: bool): ...
def SetColorPolicyRestrictComponentsDefault(default: bool): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import CatalogAPI.CatalogItem
import PyOpenColorIO as OCIO
import QT4Color as QT4Color
import QT4Color.Histogram
import PyQt5.QtCore as QtCore
import Utils as Utils
from _typeshed import Incomplete
from typing import Set, Tuple

class CatalogHistogramWidget(QT4Color.Histogram.HistogramWidget):
    def __init__(self, parent: Incomplete | None = ...) -> None: ...
    def _CatalogHistogramWidget__catalog_itemDelete_CB(self, eventType, eventID, item, **kwargs): ...
    def _CatalogHistogramWidget__catalog_itemImageUpdate_CB(self, eventType, eventID, item, **kwargs): ...
    def _CatalogHistogramWidget__doThrottledUpdate(self): ...
    def _CatalogHistogramWidget__updateImmediate(self): ...
    def _CatalogHistogramWidget__updateTimer_CB(self): ...
    def setCatalogItem(self, catalogItem: CatalogAPI.CatalogItem.CatalogItem | None): ...
    def setColorspace(self, colorspace: str): ...
    def setRect(self, rect: tuple | list[int]): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from typing import Set, Tuple

def ExplodePath(locationPath): ...
def GetLocationName(locationPath): ...
def GetParentPath(locationPath, topLevelLocationPath: str = ...): ...
def IsLocationUnderTopLevelLocation(locationPath, topLevelLocationPath): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import KatanaResources as KatanaResources
import PyQt5.QtGui
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
from typing import Set, Tuple

def GetIcon(iconType: str, res: int = ...) -> PyQt5.QtGui.QIcon: ...
def GetLargestAvailableResolution(resolution: float) -> int: ...
def GetPixmap(iconType: str, res: int = ...) -> PyQt5.QtGui.QPixmap: ...
def SetIconForLocationTypes(iconType: str, locationTypes): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import QT4FormWidgets.Conditional as Conditional
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
from QT4FormWidgets.FWidget import FBoxLayout as FBoxLayout, FButton as FButton, FDisclosureTriangle as FDisclosureTriangle, FLabel as FLabel, FLockIcon as FLockIcon, FMenu as FMenu, FPixmap as FPixmap, FSpacer as FSpacer, FStateBadge as FStateBadge, FSvgIcon as FSvgIcon, FToggleStateBadge as FToggleStateBadge, FWidget as FWidget
from QT4FormWidgets.MultiStateBadge import MultiStateBadge as MultiStateBadge, ToggleStateBadge as ToggleStateBadge, ToggleValuePolicyState as ToggleValuePolicyState
from _typeshed import Incomplete
from typing import Set, Tuple

def DeepPolicyCompare(a, b): ...
def GetTopologyDifferences(formWidgets, valuePolicies): ...
def PaintFormWidgetFrame(painter, width, topHeight, fullHeight, opened, frameWidth: Incomplete | None = ...): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import QT4FormWidgets as QT4FormWidgets
from QT4FormWidgets.GroupFormWidget import GroupFormWidget
from UI4.Widgets.MonitorManipulatorButton import MonitorManipulatorButton as MonitorManipulatorButton
from typing import Set, Tuple

class ManipulatorGroupFormWidget(GroupFormWidget):
    def __init__(self, parent, policy, factory) -> None: ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import UI4.Util.GLDrawingRoutines as GLDrawingRoutines
import NodegraphAPI as NodegraphAPI
import Nodes2DAPI as Nodes2DAPI
import PyQt5.QtCore as QtCore
import PyResolutionTableFn as ResolutionTable
import UI4 as UI4
import UI4.Util.TransformManipulatorLayer
import Utils as Utils
from UI4.FormMaster.Editors.Layers.LayerWithTransform import LayerWithTransform as LayerWithTransform
from UI4.Util.TransformManipulatorLayer import ParameterTransformGroupManipulator as ParameterTransformGroupManipulator
from typing import Set, Tuple

class Transform2DManipLayer(LayerWithTransform, UI4.Util.TransformManipulatorLayer.ParameterTransformGroupManipulator):
    def __init__(self, valuePolicy) -> None: ...
    def _Transform2DManipLayer__paintBounds(self): ...
    def _Transform2DManipLayer__portConnectionChanged(self, args): ...
    def _Transform2DManipLayer__updateAspectRatio(self): ...
    def _Transform2DManipLayer__updateBounds(self): ...
    def _Transform2DManipLayer__updateInvert(self): ...
    def _Transform2DManipLayer__updateOrder(self): ...
    def _getComponentMatrix(self, component, toPivot, fromPivot): ...
    def _paramValueChanged(self, args): ...
    def paintGL(self): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import DrawingModule as DrawingModule
import UI4.FormMaster.Editors.NodeGroup as NodeGroup
import NodegraphAPI as NodegraphAPI
import PyQt5.QtWidgets as QtWidgets
import UI4.FormMaster.Editors.NodeGroup
from typing import Set, Tuple

class OpWriteNodeEditor(UI4.FormMaster.Editors.NodeGroup.NodeGroupFormWidget):
    def __init__(self, parent, valuePolicy, widgetFactory) -> None: ...
    def _OpWriteNodeEditor__clicked(self): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import UI4.FormMaster.ParameterPolicy as ParameterPolicy
from UI4.FormMaster.BaseParameterPolicy import BaseParameterPolicy as BaseParameterPolicy
from typing import Set, Tuple

class OpaqueParameterPolicy(BaseParameterPolicy):
    def __init__(self, param, parent) -> None: ...
    def getChildByName(self, name): ...
    def getChildren(self): ...
    def getWidgetHints(self): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import KatanaResources as KatanaResources
import NodegraphAPI as NodegraphAPI
import PyQt5.QtCore
import QT4FormWidgets as QT4FormWidgets
import QT4Widgets as QT4Widgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import Nodes3DAPI.ScenegraphManager as ScenegraphManager
import UI4 as UI4
import UI4.Widgets as Widgets
from QT4FormWidgets.StringFormWidget import StringFormWidget
from typing import ClassVar, Set, Tuple

class NewScenegraphLocationEditor(ScenegraphLocationEditorBase):
    def __init__(self, parent, valuePolicy, widgetFactory) -> None: ...
    def _menuAboutToShow(self, menu): ...

class ScenegraphLocationEditor(ScenegraphLocationEditorBase):
    def __init__(self, parent, valuePolicy, widgetFactory) -> None: ...
    def _allowNodeDrops(self): ...
    def _menuAboutToShow(self, menu): ...
    def valueChangedEvent(self, event): ...

class ScenegraphLocationEditorBase(StringFormWidget):
    _icons: ClassVar[dict] = ...
    _pixmaps: ClassVar[dict] = ...
    def __init__(self, parent, valuePolicy, widgetFactory) -> None: ...
    def _ScenegraphLocationEditorBase__collectMenuAboutToShow(self, menu): ...
    def _ScenegraphLocationEditorBase__loadResources(self): ...
    def _allowNodeDrops(self): ...
    def _filterValueText(self, text): ...
    def _menuAboutToShow(self, qmenu): ...
    def checkMimeData(self, data): ...
    def event(self, event: PyQt5.QtCore.QEvent) -> bool: ...
    def getButtonMenu(self): ...
    def getMimeData(self) -> PyQt5.QtCore.QMimeData: ...
    def setMimeData(self, data, dropAction): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyFnAttribute as FnAttribute
import PyFnAttribute
import PyQt5.QtCore
import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import UI4.Widgets.SceneGraphView.SceneGraphViewColumn as SceneGraphViewColumn
import UI4.Widgets.SceneGraphView.Bridge
from UI4.Widgets.SceneGraphView.ColumnDataType import RegisterDataType as RegisterDataType
from UI4.Widgets.SceneGraphView.ItemDelegates.BaseItemDelegate import BaseItemDelegate as BaseItemDelegate
from UI4.Widgets.SceneGraphView.SceneGraphHandle import SceneGraphHandle as SceneGraphHandle
from _typeshed import Incomplete
from typing import Any, ClassVar, Set, Tuple

class BaseItemDelegate(PyQt5.QtWidgets.QStyledItemDelegate):
    MaximumColumnWidth: ClassVar[int] = ...
    _BaseItemDelegate__defaultTextColor: ClassVar[None] = ...
    def __init__(self, bridge: Bridge[UI4.Widgets.SceneGraphView.Bridge.Bridge], treeWidget: PyQt5.QtWidgets.QTreeWidget, parent: Incomplete | None = ...) -> None: ...
    def _expandRectToRightBorder(self, option: PyQt5.QtWidgets.QStyleOptionViewItem, index: PyQt5.QtCore.QModelIndex): ...
    def _getAttribute(self, locationPath: str, attributeName: str) -> PyFnAttribute.Attribute | None: ...
    def _getColumnIndices(self) -> list[int]: ...
    def _getDefaultTextColor(self) -> None: ...
    def _getLocationPath(self, index: PyQt5.QtCore.QModelIndex) -> str | None: ...
    def _getLocationType(self, locationPath: str) -> str | None: ...
    def _isLocationExpanded(self, topLevelLocationPath: str, locationPath: str) -> bool: ...
    def _repaintTreeWidgetColumns(self): ...
    def _updateColumnAttributeNames(self): ...
    def canChangeSelection(self, index: PyQt5.QtCore.QModelIndex, event: PyQt5.QtCore.QEvent) -> bool: ...
    def customizeColumnTitleContextMenu(self, menu: PyQt5.QtWidgets.QMenu): ...
    def editorEvent(self, event: PyQt5.QtCore.QEvent, model: PyQt5.QtCore.QAbstractItemModel, option: PyQt5.QtWidgets.QStyleOptionViewItem, index: PyQt5.QtCore.QModelIndex) -> bool: ...
    def getAttributeName(self) -> str | None: ...
    def getAttributeNames(self) -> list: ...
    def getAttributesForLocationPath(self, locationPath: str) -> PyFnAttribute.GroupAttribute | None: ...
    def getLocationPathsForEditing(self, editedItem: LocationTreeWidgetItem | None) -> list[str]: ...
    def getProperty(self, propertyName: str) -> Any | None: ...
    def initStyleOption(self, option: PyQt5.QtWidgets.QStyleOptionViewItem, index: PyQt5.QtCore.QModelIndex): ...
    def isEditable(self) -> bool: ...
    @classmethod
    def isPropertyValid(cls, propertyName: str) -> bool: ...
    def isValueComparisonEnabled(self) -> bool: ...
    def setAttributeName(self, attributeName: str | None, updateColumns: bool = ...): ...
    def setAttributeNames(self, attributeNames: tuple[str, ...]): ...
    def setEditable(self, editable: bool): ...
    def setProperty(self, propertyName: str, propertyValue: object | None): ...
    def setValueComparisonEnabled(self, valueComparisonEnabled: bool): ...
    def updateEditorGeometry(self, editor: PyQt5.QtWidgets.QWidget, option: PyQt5.QtWidgets.QStyleOptionViewItem, index: PyQt5.QtCore.QModelIndex): ...

class DummyItemDelegate(BaseItemDelegate):
    FixedColumnWidth: ClassVar[float] = ...
    def initStyleOption(self, option: PyQt5.QtWidgets.QStyleOptionViewItem, index: PyQt5.QtCore.QModelIndex): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import UI4.Widgets.SceneGraphView.Filtering.RuleManager as RuleManager
import UI4.Widgets.SceneGraphView.SceneGraphViewIconManager as SceneGraphViewIconManager
import typing
from UI4.Widgets.SceneGraphView.Filtering.Criteria import Criteria as Criteria
from UI4.Widgets.SceneGraphView.Filtering.Evaluator import GetEvaluatorCriteria as GetEvaluatorCriteria, GetEvaluatorInstance as GetEvaluatorInstance, GetRegisteredEvaluators as GetRegisteredEvaluators
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class CheckBoxItemDelegate(PyQt5.QtWidgets.QStyledItemDelegate):
    PaddingRight: ClassVar[int] = ...
    def __init__(self, bridge, treeWidget, getStateCallback: typing.Callable, changedHandler, parent: Incomplete | None = ...) -> None: ...
    def editorEvent(self, event, itemModel, option, index): ...
    def getCurrentStateIcon(self, ruleName): ...
    def initStyleOption(self, option, index): ...
    def sizeHint(self, option, index): ...
    def updateEditorGeometry(self, editor, option, index): ...

class ComboBoxItemDelegate(PyQt5.QtWidgets.QStyledItemDelegate):
    ITEM_HEIGHT: ClassVar[int] = ...
    def __init__(self, bridge, treeWidget, optionProviderCallback: typing.Callable, indexChangedHandler, parent: Incomplete | None = ...) -> None: ...
    def addOption(self, option): ...
    def createEditor(self, parent, option, index): ...
    def on_comboBox_currentIndexChanged(self, index): ...
    def setEditorData(self, editor, index): ...
    def setModelData(self, editor, model, index): ...
    def sizeHint(self, option, index): ...

class CriteriaEntryItemDelegate(PyQt5.QtWidgets.QStyledItemDelegate):
    ITEM_HEIGHT: ClassVar[int] = ...
    def __init__(self, bridge, treeWidget, changedHandler, parent: Incomplete | None = ...) -> None: ...
    def createEditor(self, parent, option, index): ...
    def on_criteriaValueEntry_textEdited(self, newValue): ...

class CriteriaEntryLineEdit(EntryLineEdit):
    def __init__(self, ruleName, criteriaName, parent) -> None: ...
    def getCriteriaName(self): ...
    def getRuleName(self): ...

class EntryLineEdit(PyQt5.QtWidgets.QLineEdit):
    def __init__(self, parent) -> None: ...
    def keyPressEvent(self, event): ...

class RuleComboBox(PyQt5.QtWidgets.QComboBox):
    def __init__(self, ruleName, parent) -> None: ...
    def getRuleName(self): ...

class RuleConfigDialog(PyQt5.QtWidgets.QDialog):
    COLUMN_ID_COMMENT: ClassVar[int] = ...
    COLUMN_ID_CRITERIA: ClassVar[int] = ...
    COLUMN_ID_ENABLE: ClassVar[int] = ...
    COLUMN_ID_EVALUATOR: ClassVar[int] = ...
    COLUMN_ID_INVERT: ClassVar[int] = ...
    COLUMN_ID_NAME: ClassVar[int] = ...
    COLUMN_ID_SHOWCHILDREN: ClassVar[int] = ...
    COLUMN_ID_TARGET: ClassVar[int] = ...
    COLUMN_ID_VALUE: ClassVar[int] = ...
    def __init__(self, bridge, parent: Incomplete | None = ...) -> None: ...
    def _RuleConfigDialog__getCriteriaComboList(self, ruleName): ...
    def _RuleConfigDialog__getEvaluatorOptions(self, ruleName): ...
    def _RuleConfigDialog__getRuleEnabledStateCallback(self, ruleName): ...
    def _RuleConfigDialog__getRuleInvertedStateCallback(self, ruleName): ...
    def _RuleConfigDialog__getRuleShowChildrenStateCallback(self, ruleName): ...
    def _RuleConfigDialog__getTargetOptions(self, ruleName): ...
    def _RuleConfigDialog__handleCommentValueChanged(self, index, ruleName, comment): ...
    def _RuleConfigDialog__handleCriteriaComboBoxIndexChanged(self, ruleName, newCriteria): ...
    def _RuleConfigDialog__handleCriteriaValueChanged(self, ruleName, criteriaName, criteriaValue): ...
    def _RuleConfigDialog__handleEvaluatorComboBoxIndexChanged(self, ruleName, newEvaluator): ...
    def _RuleConfigDialog__handleNameValueChanged(self, index, ruleName, newName): ...
    def _RuleConfigDialog__handleRuleEnableValueChanged(self, ruleName): ...
    def _RuleConfigDialog__handleRuleInvertValueChanged(self, ruleName): ...
    def _RuleConfigDialog__handleRuleShowChildrenValueChanged(self, ruleName): ...
    def _RuleConfigDialog__handleTargetComboBoxIndexChanged(self, ruleName, newTarget): ...
    def _RuleConfigDialog__populateEvaluatorsMenu(self): ...
    def _RuleConfigDialog__populatePolicyMenu(self): ...
    def _RuleConfigDialog__populateRuleSet(self): ...
    def _RuleConfigDialog__refreshUI(self): ...
    def _RuleConfigDialog__updateInvertMatchCheckbox(self): ...
    def on_availableRulesMenu_triggered(self, action): ...
    def on_deleteSelectedButton_clicked(self): ...
    def on_invertMatchCheckBox_stateChanged(self, state): ...
    def on_matchPolicyCombo_currentIndexChanged(self, index): ...
    def showEvent(self, event): ...

class RuleItem(PyQt5.QtWidgets.QTreeWidgetItem):
    def __init__(self, ruleName, parent) -> None: ...
    def getRuleName(self): ...
    def setRuleName(self, ruleName): ...

class TextEntryItemDelegate(PyQt5.QtWidgets.QStyledItemDelegate):
    ITEM_HEIGHT: ClassVar[int] = ...
    def __init__(self, bridge, treeWidget, changedHandler, italic: bool = ..., parent: Incomplete | None = ...) -> None: ...
    def createEditor(self, parent, option, index): ...
    def initStyleOption(self, option, index): ...
    def setModelData(self, editor, model, index): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import NodegraphAPI as NodegraphAPI
import UI4.KatanaPrefs.PrefNames as PrefNames
import PyQt5.QtCore
import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtWidgets as QtWidgets
import Utils as Utils
from UI4.KatanaPrefs.KatanaPrefsObject import Prefs as Prefs
from typing import ClassVar, Set, Tuple

class CheckList(PyQt5.QtWidgets.QListWidget):
    def mousePressEvent(self, event): ...
    def mouseReleaseEvent(self, event): ...

class EditMenuDialog(PyQt5.QtWidgets.QDialog):
    def __init__(self, parent, ignoreTags) -> None: ...
    def doReset(self): ...
    def getActiveTags(self): ...

class NodeMenu(PyQt5.QtWidgets.QMenu):
    nodeSelected: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, parent, onlyTags: tuple = ..., ignoreTags: tuple = ...) -> None: ...
    def _NodeMenu__NodeSetsByCategory(self, nodes): ...
    def _NodeMenu__addSubMenuNodes(self, name, nodesTuple): ...
    def _NodeMenu__addSubMenus(self, name, allNodes, tags, showAll, otherStr: str = ...): ...
    def _NodeMenu__createHierMenu(self, path, origParent, hierMenus): ...
    def _NodeMenu__doAboutToShow(self): ...
    def _NodeMenu__doActivated(self, action): ...
    def _NodeMenu__doEditMenus(self): ...
    def _NodeMenu__doRetagged(self, event, eventId, **kwargs): ...
    def _NodeMenu__getNodesWithTag(self, nodes, tag): ...
    def _NodeMenu__rebuildMenu(self): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import ConfigurationAPI_cmodule as Configuration
import KatanaResources as KatanaResources
import PyQt5.QtCore as QtCore
import Utils as Utils
from _typeshed import Incomplete
from typing import Set, Tuple

class KatanaPrefsObject:
    def __init__(self) -> None: ...
    def _KatanaPrefsObject__declarePref(self, key: str, typeName: str, helpText: Incomplete | None = ..., visible: bool = ..., hints: Incomplete | None = ..., enabled: bool = ...): ...
    def commit(self): ...
    def declareBoolPref(self, key, default, helpText, visible: bool = ..., hints: Incomplete | None = ..., enabled: bool = ...): ...
    def declareColorPref(self, key, default, helpText, visible: bool = ..., hints: Incomplete | None = ..., enabled: bool = ...): ...
    def declareDoublePref(self, key, default, helpText, visible: bool = ..., hints: Incomplete | None = ..., enabled: bool = ...): ...
    def declareGroupPref(self, key, visible: bool = ..., hints: Incomplete | None = ...): ...
    def declareIntPref(self, key, default, helpText, visible: bool = ..., hints: Incomplete | None = ..., enabled: bool = ...): ...
    def declareScenegraphColumnDescriptionPref(self, key, default, helpText, visible: bool = ..., hints: Incomplete | None = ..., enabled: bool = ...): ...
    def declareStringPref(self, key, default, helpText, visible: bool = ..., hints: Incomplete | None = ..., enabled: bool = ...): ...
    def flush(self): ...
    def getChildPrefs(self, key): ...
    def getHelpText(self, key): ...
    def getHints(self, key): ...
    def getType(self, key): ...
    def getVersion(self): ...
    def getVisible(self, key): ...
    def keys(self): ...
    def setVersion(self, prefsVersion): ...
    def shutdownCommit(self): ...
    def __contains__(self, item) -> bool: ...
    def __getitem__(self, key): ...
    def __len__(self) -> int: ...
    def __setitem__(self, key, value) -> None: ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import ConfigurationAPI_cmodule as Configuration
import Naming as Naming
import NodegraphAPI as NodegraphAPI
import Nodes2DAPI as Nodes2DAPI
import PyOpenColorIO as OCIO
import PyQt5.QtWidgets
import QT4FormWidgets as QT4FormWidgets
import PyQt5.QtWidgets as QtWidgets
import PyResolutionTableFn as ResolutionTable
import UI4 as UI4
from PyUtilModule.VirtualKatana import RenderManager as RenderManager
from UI4.Widgets.FlipbookDialog import FlipbookDialog as FlipbookDialog
from typing import Set, Tuple

_dialogPolicy: None

class FlipbookSettingsDialog(PyQt5.QtWidgets.QDialog):
    def __init__(self, node: NodegraphAPI.Node, *args) -> None: ...
    def accept(self): ...
    def getArguments(self): ...

def GetDialogPolicy(): ...
def _GetIntersectedROI(roi, displayWindow): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyFnAttribute as FnAttribute
import KatanaResources as KatanaResources
import NodegraphAPI as NodegraphAPI
import Utils as Utils
import PyXmlIO as XmlIO
from Utils.Decorators import deprecated as deprecated
from _typeshed import Incomplete
from typing import Set, Tuple

def BuildAttrFromParsedEntry(element, refDict: Incomplete | None = ...): ...
def GetGenericAppenderLocations(): ...
def InitGenericAppenders(path: Incomplete | None = ...): ...
def ParseArgsFile(filename): ...
def ParseArgsString(xmlString): ...
def RegisterAppenderNodeTypes(searchPath: Incomplete | None = ...): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import RenderingAPI as RenderingAPI
from typing import ClassVar, Set, Tuple

class RenderModes:
    DISK_RENDER: ClassVar[str] = ...
    DISK_RENDER_MENU_KEY: ClassVar[str] = ...
    LIVE_RENDER: ClassVar[str] = ...
    LIVE_RENDER_MENU_KEY: ClassVar[str] = ...
    MENU_ACTIONS: ClassVar[dict] = ...
    MENU_COMMANDS: ClassVar[dict] = ...
    MENU_ORDER: ClassVar[list] = ...
    MENU_PLURALS: ClassVar[dict] = ...
    MENU_TITLES: ClassVar[dict] = ...
    PREVIEW_RENDER: ClassVar[str] = ...
    PREVIEW_RENDER_MENU_KEY: ClassVar[str] = ...
    PROFILE_RENDER_MENU_KEY: ClassVar[str] = ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import CatalogAPI as CatalogAPI
import ConfigurationAPI_cmodule as Configuration
import PyFnGeolib as FnGeolib
import PyFnGeolibProducers as FnGeolibProducers
import PyUtilModule.RenderManager.InteractiveRenderDelegateManager as InteractiveRenderDelegateManager
import NodegraphAPI as NodegraphAPI
import Nodes2DAPI as Nodes2DAPI
import Nodes3DAPI as Nodes3DAPI
import PyUtilModule.ProjectSnapshot as ProjectSnapshot
import PyUtilModule.RenderManager.RenderGlobals as RenderGlobals
import RenderingAPI as RenderingAPI
import PyUtilModule.RenderingCommon as RenderingCommon
import Utils as Utils
import typing
from PyUtilModule.RenderManager.Constants import RenderModes as RenderModes
from PyUtilModule.RenderManager.Exceptions import RenderingException as RenderingException, UnsupportedRenderMethodNameException as UnsupportedRenderMethodNameException
from PyUtilModule.RenderManager.NodegraphUtils import ApplyInteractiveRenderDelegates as ApplyInteractiveRenderDelegates, BuildRenderPortsAndGraphStatesList as BuildRenderPortsAndGraphStatesList, CollapseNodesAndPorts as CollapseNodesAndPorts, CreateRenderNodeParameters as CreateRenderNodeParameters, DisableKatanaNodeGraphEventProcessing as DisableKatanaNodeGraphEventProcessing, GetSourcePortsAndNamesFromLists as GetSourcePortsAndNamesFromLists, IsScriptRender as IsScriptRender, NotifyIfInteractiveRerender as NotifyIfInteractiveRerender
from PyUtilModule.RenderManager.RenderSettings import CheckGlobalSettings as CheckGlobalSettings, GetRendererAndSettings as GetRendererAndSettings, RenderingSettings as RenderingSettings
from PyUtilModule.RenderManager.ResolutionTableUtils import GetTempResolutionTablePath as GetTempResolutionTablePath, SaveResolutionTables as SaveResolutionTables
from PyUtilModule.RenderManager.ScenegraphUtils import AddCameraOverrideToRecipe as AddCameraOverrideToRecipe, AddRenderOutputsToRecipe as AddRenderOutputsToRecipe, AddRenderSettingsToRecipe as AddRenderSettingsToRecipe, AddVirtualCameraToRecipe as AddVirtualCameraToRecipe, BakeAOVs as BakeAOVs, GetInteractiveOutputs as GetInteractiveOutputs
from Utils.Decorators import deprecated as deprecated
from _typeshed import Incomplete
from typing import Set, Tuple

class RenderComponents:
    def __init__(self) -> None: ...

def CancelRender(stallOnCompletion: bool = ..., mainSequenceID: int = ..., **kwargs): ...
def CancelRendersByType(renderType: int, stallOnCompletion: bool = ..., predicate: Incomplete | None = ...): ...
def StartRender(renderMethodName: str, node: typing.Optional[NodegraphAPI.Node] = ..., port: typing.Optional[NodegraphAPI.Port] = ..., nodeList: Incomplete | None = ..., portList: Incomplete | None = ..., serialDiskRenderNodeList: Incomplete | None = ..., views: Incomplete | None = ..., settings: Incomplete | None = ..., **kwargs) -> list[dict]: ...
def StartRenderLegacy(node: typing.Optional[NodegraphAPI.Node] = ..., port: typing.Optional[NodegraphAPI.Port] = ..., nodeList: Incomplete | None = ..., portList: Incomplete | None = ..., serialHotrenderNodeList: Incomplete | None = ..., views: Incomplete | None = ..., saveRenderXML: bool = ..., hotRender: bool = ..., ROI: Incomplete | None = ..., ignoreROI: bool = ..., overscanPadding: Incomplete | None = ..., sampleRate: Incomplete | None = ..., frame: Incomplete | None = ..., interactive: bool = ..., useID: Incomplete | None = ..., interactiveOutputs: Incomplete | None = ..., emitTileRenderOrdering: bool = ..., diskCachingAllowed: Incomplete | None = ..., tilePrioritizer: Incomplete | None = ..., buffer2DAutoLock: Incomplete | None = ..., interactiveRenderMask: Incomplete | None = ..., createCatalogItem: Incomplete | None = ..., asynch: bool = ..., asynch_renderMessageCB: Incomplete | None = ..., asynch_renderProgressCB: Incomplete | None = ..., serialHotrender_progressCB: Incomplete | None = ..., render_completionCB: Incomplete | None = ..., renderMethodName: Incomplete | None = ...): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtGui
import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import UI4.App.Tabs as Tabs
from UI4.Tabs.BaseTab import BaseTab as BaseTab
from UI4.Widgets.LogRecordTreeView import LogRecordTreeView as LogRecordTreeView
from _typeshed import Incomplete
from typing import Set, Tuple

PluginRegistry: list

class MessagesTab(BaseTab):
    def __init__(self, parent: Incomplete | None = ...) -> None: ...
    def _MessagesTab__updateTabTitle(self): ...
    def applySettings(self, settings: dict): ...
    def getMenuBar(self) -> PyQt5.QtWidgets.QMenuBar | None: ...
    def getSettings(self) -> dict: ...
    def on_treeView_activeLevelNamesChanged(self, activeLevelNames: list[str]): ...
    def showEvent(self, event: PyQt5.QtGui.QShowEvent): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import DrawingModule as DrawingModule
import NodeGraphView as NodeGraphView
import NodegraphAPI as NodegraphAPI
import Nodes2DAPI as Nodes2DAPI
import Nodes3DAPI as Nodes3DAPI
import QT4Color as QT4Color
import QT4Widgets as QT4Widgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import PyUtilModule.RenderManager.RenderGlobals as RenderGlobals
import PyUtilModule.RenderManager as RenderManager
import Nodes3DAPI.ScenegraphManager as ScenegraphManager
import UI4 as UI4
import Utils as Utils
import QT4Widgets.WidgetUtils as WidgetUtils
from . import AttributeHistoryWidgets as AttributeHistoryWidgets, AutoKeyToggle as AutoKeyToggle, BaseWidgets as BaseWidgets, CatalogRenderStatsWidget as CatalogRenderStatsWidget, CollectAndSelect as CollectAndSelect, DoubleSpinBox as DoubleSpinBox, FilterPopups as FilterPopups, GradientLayer as GradientLayer, ImageOptionsWidgets as ImageOptionsWidgets, MessageBox as MessageBox, PaneButtons as PaneButtons, ProductSaveWidgets as ProductSaveWidgets, RenderModePopup as RenderModePopup, RenderViewWidgets as RenderViewWidgets, ScrollAreaMemory as ScrollAreaMemory, SortableGroups as SortableGroups, SortablePanel as SortablePanel, SortableParams as SortableParams, StatefulMenu as StatefulMenu, UpdateModeWidgets as UpdateModeWidgets, VariablesPopup as VariablesPopup, WorkingSetWidgets as WorkingSetWidgets
from .SceneGraphView import Bridge as Bridge, ColumnManager as ColumnManager, ColumnPresetManager as ColumnPresetManager, ContextMenuEvent as ContextMenuEvent, SceneGraphLocationTranslation as SceneGraphLocationTranslation, SceneGraphTree as SceneGraphTree, SceneGraphViewClientManager as SceneGraphViewClientManager, SceneGraphViewColumn as SceneGraphViewColumn, SceneGraphViewIconManager as SceneGraphViewIconManager, ViewLink as ViewLink
from QT4Widgets.CustomMenu import CustomMenu as CustomMenu
from QT4Widgets.FilterFieldWidget import FilterFieldWidget as FilterFieldWidget
from QT4Widgets.FilterablePopupButton import FilterablePopup as FilterablePopup, FilterablePopupButton as FilterablePopupButton
from QT4Widgets.MenuButton import MenuButton as MenuButton
from QT4Widgets.PopdownLabel import PopdownLabel as PopdownLabel
from QT4Widgets.SortableTreeWidget import CallbackRecord as CallbackRecord, SortableTreeWidget as SortableTreeWidget, SortableTreeWidgetItem as SortableTreeWidgetItem, SortableTreeWidgetItemDelegate as SortableTreeWidgetItemDelegate
from QT4Widgets.StretchBox import StretchBox as StretchBox
from UI4.Util.IconManager import GetPixmap as GetPixmap
from UI4.Widgets.AssetIDLabel import AssetIDLabel as AssetIDLabel
from UI4.Widgets.AttributeDropLabel import AttributeDropLabel as AttributeDropLabel
from UI4.Widgets.AttributeEditorIndicatorLabel import AttributeEditorIndicatorLabel as AttributeEditorIndicatorLabel
from UI4.Widgets.AttributeHistoryWidgets import AddAttributeHistoryActionsToMenu as AddAttributeHistoryActionsToMenu, AttributeHistoryPopup as AttributeHistoryPopup, AttributeHistoryPopupWidget as AttributeHistoryPopupWidget, AttributeHistoryTreeWidget as AttributeHistoryTreeWidget, AttributeInheritancePopup as AttributeInheritancePopup, AttributeInheritancePopupWidget as AttributeInheritancePopupWidget
from UI4.Widgets.AutoKeyToggle import AutoKeyAllToggle as AutoKeyAllToggle
from UI4.Widgets.BaseLayoutResizer import BaseLayoutResizer as BaseLayoutResizer
from UI4.Widgets.BaseNodeGraphLayerStack import BaseNodeGraphLayerStack as BaseNodeGraphLayerStack
from UI4.Widgets.BaseWidgets import BaseFrame as BaseFrame, BaseWidget as BaseWidget
from UI4.Widgets.CameraPickerButton import CameraPickerButton as CameraPickerButton
from UI4.Widgets.CatalogChannelsWidget import CatalogChannelsWidget as CatalogChannelsWidget
from UI4.Widgets.CatalogFrameRangeWidget import CatalogFrameRangeWidget as CatalogFrameRangeWidget
from UI4.Widgets.CatalogHistogramWidget import CatalogHistogramWidget as CatalogHistogramWidget
from UI4.Widgets.CatalogItemWidget import CatalogItemWidget as CatalogItemWidget
from UI4.Widgets.CatalogLockWidget import CatalogLockWidget as CatalogLockWidget
from UI4.Widgets.CatalogNameWidget import CatalogNameWidget as CatalogNameWidget
from UI4.Widgets.CatalogProgressWidget import CatalogProgressWidget as CatalogProgressWidget, ProgressWidget as ProgressWidget
from UI4.Widgets.CatalogRenderLogWidget import CatalogRenderLogWidget as CatalogRenderLogWidget
from UI4.Widgets.CatalogRenderStatsWidget import CatalogRenderGlobalsStatsWidget as CatalogRenderGlobalsStatsWidget, CatalogRenderTaskByNameStatsWidget as CatalogRenderTaskByNameStatsWidget, CatalogRenderTaskByTypeStatsWidget as CatalogRenderTaskByTypeStatsWidget
from UI4.Widgets.CatalogResolutionWidget import CatalogResolutionWidget as CatalogResolutionWidget
from UI4.Widgets.CatalogStopWidget import CatalogStopWidget as CatalogStopWidget
from UI4.Widgets.CatalogThumbnailWidget import CatalogThumbnailWidget as CatalogThumbnailWidget
from UI4.Widgets.CelResultsWidget import CelResultsWidget as CelResultsWidget, CelResultsWindow as CelResultsWindow
from UI4.Widgets.CheckableTreeDialog import CheckableTreeDialog as CheckableTreeDialog
from UI4.Widgets.Checkbox import Checkbox as Checkbox
from UI4.Widgets.CollectAndSelect import CollectAndSelectInScenegraph as CollectAndSelectInScenegraph
from UI4.Widgets.ColorProbeButton import ColorProbeBase as ColorProbeBase, ColorProbeButton as ColorProbeButton
from UI4.Widgets.ComboBoxNoWheel import ComboBoxNoWheel as ComboBoxNoWheel
from UI4.Widgets.CrashFileSelectorDialog import CrashFileSelectorDialog as CrashFileSelectorDialog
from UI4.Widgets.DoubleClickSizeGrip import DoubleClickSizeGrip as DoubleClickSizeGrip
from UI4.Widgets.DropdownArrowButton import DropdownArrowButton as DropdownArrowButton
from UI4.Widgets.EditWrenchButton import EditWrenchButton as EditWrenchButton
from UI4.Widgets.FarmDefaultDialog import FarmDefaultDialog as FarmDefaultDialog, GenerateFarmCreateSettingsOnRootNode as GenerateFarmCreateSettingsOnRootNode
from UI4.Widgets.FastLabel import FastLabel as FastLabel
from UI4.Widgets.FilterPopups import LookFileMaterialFilterPopup as LookFileMaterialFilterPopup, ShaderFilterPopup as ShaderFilterPopup, ShaderTypeFilterPopup as ShaderTypeFilterPopup
from UI4.Widgets.FlipbookDialog import FlipbookDialog as FlipbookDialog
from UI4.Widgets.GeolibProcessingStateWidget import GeolibProcessingStateWidget as GeolibProcessingStateWidget
from UI4.Widgets.GetSetMenu import GetSetAction as GetSetAction, GetSetMenu as GetSetMenu
from UI4.Widgets.GradientLayer import GradientLayerBundle as GradientLayerBundle, GradientLayerBundleManager as GradientLayerBundleManager, HueGradientFCurveLayer as HueGradientFCurveLayer, HueGradientLayerStackLayer as HueGradientLayerStackLayer, LinearGradientFCurveLayer as LinearGradientFCurveLayer, LinearGradientLayerStackLayer as LinearGradientLayerStackLayer
from UI4.Widgets.GraphStateVariablesPopupButton import GraphStateVariablesPopupButton as GraphStateVariablesPopupButton
from UI4.Widgets.HBoxLayoutResizer import HBoxLayoutResizer as HBoxLayoutResizer
from UI4.Widgets.HighlightWidget import HighlightWidget as HighlightWidget
from UI4.Widgets.HistogramLayer import HistogramLayer as HistogramLayer
from UI4.Widgets.HorizontalDivider import HorizontalDivider as HorizontalDivider
from UI4.Widgets.HtmlEditorWidget import HtmlEditorWidget as HtmlEditorWidget
from UI4.Widgets.IconLabelFrame import IconLabelFrame as IconLabelFrame
from UI4.Widgets.ImageOptionsWidgets import ColorspaceSelectionWidget as ColorspaceSelectionWidget, ImageOptionsWidget as ImageOptionsWidget, OptionComboBase as OptionComboBase, OutputImageExtensionWidget as OutputImageExtensionWidget
from UI4.Widgets.ImplicitFilterToggle import ImplicitFilterToggle as ImplicitFilterToggle, ImplicitFilterWarningLabel as ImplicitFilterWarningLabel
from UI4.Widgets.IndicatorLabelFrame import IndicatorLabelFrame as IndicatorLabelFrame
from UI4.Widgets.KeyboardShortcutLineEdit import KeyboardShortcutLineEdit as KeyboardShortcutLineEdit
from UI4.Widgets.LiveRenderViewerCameraButton import LiveRenderViewerCameraButton as LiveRenderViewerCameraButton
from UI4.Widgets.LogRecordTreeView import LogRecordTreeView as LogRecordTreeView
from UI4.Widgets.LookFileMaterialComboBox import LookFileMaterialComboBox as LookFileMaterialComboBox
from UI4.Widgets.MessagesToolbarButton import MessagesToolbarButton as MessagesToolbarButton
from UI4.Widgets.MetaCheckBox import MetaCheckBox as MetaCheckBox
from UI4.Widgets.ModalProcessInterruptWidget import ModalProcessInterruptWidget as ModalProcessInterruptWidget
from UI4.Widgets.MonitorManipulatorButton import MonitorManipulatorButton as MonitorManipulatorButton
from UI4.Widgets.NavigationToolbar import NavigationToolbar as NavigationToolbar
from UI4.Widgets.NodeButton import NodeButton as NodeButton
from UI4.Widgets.NodeChooserButton import NodeChooserButton as NodeChooserButton
from UI4.Widgets.NodeColorsMenu import ColorAction as ColorAction, NodeColorsMenu as NodeColorsMenu, SetNodeColorCustom as SetNodeColorCustom
from UI4.Widgets.NodeMenu import NodeMenu as NodeMenu
from UI4.Widgets.NodePopupMenu import NodePopupMenu as NodePopupMenu, PortRenameWidget as PortRenameWidget, ShadingPortPopupMenu as ShadingPortPopupMenu
from UI4.Widgets.NodeTypePopup import NodeTypePopup as NodeTypePopup
from UI4.Widgets.NonexclusiveCheckboxPopup import NonexclusiveCheckboxPopup as NonexclusiveCheckboxPopup
from UI4.Widgets.NotificationToolbarButton import NotificationToolbarButton as NotificationToolbarButton
from UI4.Widgets.PaneButtons import AddTabButton as AddTabButton, CloseAllTabsButton as CloseAllTabsButton, CloseTabButton as CloseTabButton, MaximizePaneButton as MaximizePaneButton
from UI4.Widgets.PanelScrollArea import PanelScrollArea as PanelScrollArea
from UI4.Widgets.PanelWidget import PanelWidget as PanelWidget
from UI4.Widgets.PolicyHelpButton import PolicyHelpButton as PolicyHelpButton
from UI4.Widgets.PopdownLabel import LabelButton as LabelButton
from UI4.Widgets.PopupButton import PopupButton as PopupButton
from UI4.Widgets.PortNameLineEdit import PortNameLineEdit as PortNameLineEdit
from UI4.Widgets.ProductSaveWidgets import FileSaveDialog as FileSaveDialog, FileSaveWidget as FileSaveWidget, ProductOrFileSaveDialog as ProductOrFileSaveDialog, ProductSaveDialog as ProductSaveDialog
from UI4.Widgets.ProgressDialog import ProgressDialog as ProgressDialog
from UI4.Widgets.ProxyResCombo import ProxyResCombo as ProxyResCombo
from UI4.Widgets.PublicInterfaceParameters import PublicInterfaceParameters as PublicInterfaceParameters
from UI4.Widgets.RenderModePopup import RenderModePopupButton as RenderModePopupButton
from UI4.Widgets.RenderSelectedToggle import RenderSelectedToggle as RenderSelectedToggle
from UI4.Widgets.RenderViewWidgets import RenderViewCapsule as RenderViewCapsule, RenderViewsAutoUpdateCheckbox as RenderViewsAutoUpdateCheckbox
from UI4.Widgets.ResizeToggleArrow import ResizeToggleArrow as ResizeToggleArrow
from UI4.Widgets.ResolutionComboBox import ResolutionComboBox as ResolutionComboBox
from UI4.Widgets.RoiCombo import RoiCombo as RoiCombo
from UI4.Widgets.RolloverPixmap import RolloverPixmap as RolloverPixmap
from UI4.Widgets.SceneGraphView.ColumnDataType import ColumnDataType as ColumnDataType, RegisterDataType as RegisterDataType
from UI4.Widgets.SceneGraphView.HorizontalHeaderView import HorizontalHeaderView as HorizontalHeaderView
from UI4.Widgets.SceneGraphView.SceneGraphView import SceneGraphView as SceneGraphView
from UI4.Widgets.ServiceProviderListWidget import ServiceProviderListWidget as ServiceProviderListWidget
from UI4.Widgets.SetVersionFilterablePopup import SetVersionFilterablePopup as SetVersionFilterablePopup
from UI4.Widgets.ShaderComboBox import ShaderComboBox as ShaderComboBox
from UI4.Widgets.ShelfButton import ShelfButton as ShelfButton
from UI4.Widgets.SortableGroups import SortableGroupsFormWidget as SortableGroupsFormWidget
from UI4.Widgets.SortableListWidget import SortableListWidget as SortableListWidget, SortableListWidgetItem as SortableListWidgetItem, SortableListWidgetItemDelegate as SortableListWidgetItemDelegate
from UI4.Widgets.SortablePanel import ParameterExpressionPanel as ParameterExpressionPanel, ParameterSortablePanel as ParameterSortablePanel, ParameterSortablePanelFormWidget as ParameterSortablePanelFormWidget, SortablePanelBase as SortablePanelBase, SortablePanelFormWidget as SortablePanelFormWidget
from UI4.Widgets.SortableParams import SortableParamsFormWidget as SortableParamsFormWidget
from UI4.Widgets.StopButton import SimpleStopWidget as SimpleStopWidget, StopButton as StopButton
from UI4.Widgets.SwitchingBoxLayout import SwitchingBoxLayout as SwitchingBoxLayout
from UI4.Widgets.TabDockWidget import TabDockWidget as TabDockWidget
from UI4.Widgets.ToolbarButton import LabeledToolbarButton as LabeledToolbarButton, ToolbarButton as ToolbarButton
from UI4.Widgets.ToolbarWidget import ToolbarWidget as ToolbarWidget
from UI4.Widgets.TreeWidget import TreeItem as TreeItem, TreeWidget as TreeWidget
from UI4.Widgets.TriangleButton import TriangleButton as TriangleButton
from UI4.Widgets.UpdateModeWidgets import UpdateModePopdownButton2D as UpdateModePopdownButton2D, UpdateModePopdownButton3D as UpdateModePopdownButton3D, UpdateModeWidget2D as UpdateModeWidget2D, UpdateModeWidget3D as UpdateModeWidget3D
from UI4.Widgets.VBoxLayoutResizer import VBoxLayoutResizer as VBoxLayoutResizer
from UI4.Widgets.VPStateButton import VPStateButton as VPStateButton
from UI4.Widgets.VariablesPopup import VariablesPopupButton as VariablesPopupButton
from UI4.Widgets.VerticalDivider import VerticalDivider as VerticalDivider
from UI4.Widgets.ViewIndicatorLabel import ViewIndicatorLabel as ViewIndicatorLabel
from UI4.Widgets.ViewerWorkingSetButton import ViewerWorkingSetButton as ViewerWorkingSetButton
from UI4.Widgets.ViewportPane import ViewportPane as ViewportPane
from UI4.Widgets.ViewportWidget import ViewportWidget as ViewportWidget
from UI4.Widgets.WheelEventIgnoringTabBar import WheelEventIgnoringTabBar as WheelEventIgnoringTabBar
from UI4.Widgets.WidgetHilightBox import WidgetHilightBox as WidgetHilightBox
from UI4.Widgets.WorkingSetWidgets import WorkingSetClearStateAction as WorkingSetClearStateAction, WorkingSetContextMenu as WorkingSetContextMenu, WorkingSetExpandBranchAction as WorkingSetExpandBranchAction, WorkingSetIconManager as WorkingSetIconManager, WorkingSetIncludeProxyChildren as WorkingSetIncludeProxyChildren, WorkingSetResetStateAction as WorkingSetResetStateAction, WorkingSetStateAction as WorkingSetStateAction, WorkingSetStateCheckableAction as WorkingSetStateCheckableAction
from typing import Set, Tuple

def Initialize(): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from typing import Set, Tuple

class Record:
    def __init__(self: int, index: str, title: str, text: int, level: int, timestamp: str | None, iconName) -> None: ...
    def getIconName(self) -> str | None: ...
    def getIndex(self) -> int: ...
    def getLevel(self) -> int: ...
    def getText(self) -> str: ...
    def getTimestamp(self) -> int: ...
    def getTitle(self) -> str: ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import Nodes2DAPI as Nodes2DAPI
import Utils as Utils
from _typeshed import Incomplete
from typing import Set, Tuple

def drawEllipse(xRadius, yRadius, startAngle, endAngle, steps, filled: bool = ...): ...
def drawSmoothArrow(color, trans, basePt, endPt, lineWidth, filled: bool = ...): ...
def drawSmoothCross(color, trans, px, py, xSize, ySize, lineWidth): ...
def drawSmoothCrosshairs(color, trans, px, py, startRadius, endRadius, lineWidth): ...
def drawSmoothEllipse(color, trans, px, py, xRadius, yRadius, startAngle, endAngle, steps, lineWidth, filled: bool = ...): ...
def drawSmoothHandle(color, trans, edgeSize, px, py, lineWidth, filled: bool = ...): ...
def drawSmoothPoly(color, trans, vertices, lineWidth, stippled: bool = ..., fillColor: Incomplete | None = ...): ...
def drawSmoothText(text, color, trans, px, py, fontSize): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtWidgets
import QT4FormWidgets as QT4FormWidgets
import QT4FormWidgets.ValuePolicy
import QT4Widgets as QT4Widgets
import RenderingAPI as RenderingAPI
import UI4 as UI4
import Utils as Utils
from QT4FormWidgets.BaseValueFormWidget import BaseValueFormWidget
from QT4FormWidgets.FilterablePopupFormWidget import FilterablePopupFormWidget
from QT4FormWidgets.FilterablePopupFormWidget.FilterablePopupFormWidget import PopupButton
from QT4FormWidgets.FormWidget import FormWidget
from QT4FormWidgets.WidgetFactory import WidgetFactory
from _typeshed import Incomplete
from typing import Set, Tuple

class ShaderPopupFormWidget(BaseValueFormWidget):
    def __init__(self, parent: PyQt5.QtWidgets.QWidget, policy: QT4FormWidgets.ValuePolicy.AbstractValuePolicy, factory: WidgetFactory) -> None: ...
    def _ShaderPopupFormWidget__browseCallback(self): ...
    def _ShaderPopupFormWidget__on_shaderComboBox_itemChosen(self, text: str, meta: str): ...
    def _buildControlWidget(self, layout): ...
    def _buildLabel(self, labelText, pos: int = ...): ...
    def _lockChanged(self, state): ...
    def _updateControlWidget(self): ...

class ShaderTypeMenuWidget(FormWidget):
    def __init__(self, parent, valuePolicy, widgetFactory) -> None: ...
    def _ShaderTypeMenuWidget__addMenuItem(self, item, renderer: Incomplete | None = ...): ...
    def _ShaderTypeMenuWidget__getRenderInfoPlugin(self, rendererName): ...
    def _ShaderTypeMenuWidget__selectShaderType(self, materialType, rendererName): ...
    def _lockChanged(self, state): ...
    def _thaw(self): ...
    def refresh(self): ...

class ShaderTypePopupFormWidget(FilterablePopupFormWidget):
    class ShaderTypePopupButton(PopupButton):
        def _buildPopupWindow(self): ...
    def __init__(self, parent, policy, factory) -> None: ...
    def _ShaderTypePopupFormWidget__itemChosen(self): ...
    def _buildPopupButton(self): ...

class SimpleMenuWidget(FormWidget):
    def __init__(self, parent, valuePolicy, widgetFactory) -> None: ...
    def _SimpleMenuWidget__addMenuItem(self, item): ...
    def _SimpleMenuWidget__selectType(self, item): ...
    def refresh(self): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import ConfigurationAPI_cmodule as Configuration
import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class CallersCalleesNavigationPopup(PyQt5.QtWidgets.QFrame):
    ASSOCIATED_FUNCTION_COLUMN_INDEX: ClassVar[int] = ...
    FUNCTION_TYPE: ClassVar[dict] = ...
    def __init__(self, functionName, functionType, parent: Incomplete | None = ...) -> None: ...
    def on_callersCalleesButtons_clicked(self, functionType): ...
    def on_goBackButton_clicked(self): ...
    def updateCalleesCallersPopup(self, functionName, functionType): ...

class ProfileStatsWidget(PyQt5.QtWidgets.QFrame):
    PROFILE_FILEPATH: ClassVar[str] = ...
    TAB_RESOURCES_DIR: ClassVar[str] = ...
    def __init__(self, parent, stats: Incomplete | None = ..., defaultStatusText: str = ...) -> None: ...
    def on_callersCalleesAction_triggered(self, func, functionType): ...
    def setStats(self, stats, statusText: Incomplete | None = ...): ...
    def setStatusText(self, message): ...

class ProfileTreeWidgetItem(PyQt5.QtWidgets.QTreeWidgetItem):
    def __init__(self, parent, func, stats) -> None: ...
    def __lt__(self, other) -> bool: ...

def main(): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from typing import Set, Tuple

def CropWindowToImageRect(dataWindow, cropWindow): ...
def ImageRectToCropWindow(dataWindow, imageRect): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtCore
import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtWidgets as QtWidgets
import PyUtilModule.RenderManager as RenderManager
import Utils as Utils
from QT4Widgets.PopdownLabel import PopdownLabel as PopdownLabel
from typing import ClassVar, Set, Tuple

class RoiCombo(PopdownLabel):
    roiVisibilityChanged: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, parent) -> None: ...
    def _RoiCombo__renderManager_roiChanged_callback(self, *args, **kwargs): ...
    def buildMenu(self, menu: PyQt5.QtWidgets.QMenu): ...
    def getRoiVisible(self): ...
    def setRoiVisible(self, isVisible): ...
    def updateState(self): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import QT4GLLayerStack as QT4GLLayerStack
import QT4GLLayerStack.LayerStack
import QT4Widgets as QT4Widgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import UI4 as UI4
from UI4.Tabs.Monitor.Layers.ImageLayerBase import ImageLayerBase as ImageLayerBase
from typing import Set, Tuple

class ImageLayer(QT4GLLayerStack.LayerStack.Layer, ImageLayerBase):
    def __init__(self, *args, **kwargs) -> None: ...
    def getViewIndexFromWindowPos(self, qpos): ...
    def paintDropArea(self, dropColor): ...
    def paintGL(self): ...
    def processEvent(self, event): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtGui as QtGui
import Utils as Utils
from UI4.Util.IconManager import GetPixmap as GetPixmap
from UI4.Widgets.ToolbarButton import ToolbarButton as ToolbarButton
from typing import ClassVar, Set, Tuple

class SimpleStopWidget(ToolbarButton):
    _SimpleStopWidget__DEFAULT_LABEL: ClassVar[str] = ...
    _SimpleStopWidget__NUM_PIXMAPS: ClassVar[int] = ...
    def __init__(self, parent, small: bool = ..., showPreselect: bool = ..., clickable: bool = ...) -> None: ...
    def _SimpleStopWidget__released(self): ...
    def advanceTick(self): ...
    def getActive(self): ...
    def isClickable(self): ...
    def isStopping(self): ...
    def mousePressEvent(self, event): ...
    def resetButton(self, frame: int = ..., disable: bool = ...): ...
    def setActive(self, active): ...
    def setClickable(self, clickable): ...
    def setStopping(self, stopping): ...

class StopButton(SimpleStopWidget):
    def __init__(self, parent) -> None: ...
    def _StopButton__clickedCallback(self): ...
    def connectToWorkQueue(self, workQueue): ...
    def getPixmapSize(self): ...
    def start(self): ...
    def startEvent(self, eventName, eventId, **kwargs): ...
    def stop(self): ...
    def stopEvent(self, eventName, eventId, **kwargs): ...
    def tickEvent(self, eventName, eventId, **kwargs): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import NodegraphAPI as NodegraphAPI
import PyQt5.QtCore as QtCore
import PyQt5.QtWidgets as QtWidgets
from UI4.Tabs.NodeGraphTab.Layers.LinkConnectionLayer import LinkConnectionLayer as LinkConnectionLayer
from typing import Set, Tuple

class StructuredPortsNodeLinkConnectionLayer(LinkConnectionLayer):
    def __init__(self, interactionLayer, structuredPorts, *args, **kwargs) -> None: ...
    def _StructuredPortsNodeLinkConnectionLayer__linkConnectionPortChosenCallback(self, item, meta, nodeName): ...
    def processMousePress(self, event): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from . import Common2D as Common2D, General as General, ImageAddMix as ImageAddMix, ImageBackgroundColor as ImageBackgroundColor, ImageBlur as ImageBlur, ImageBrightness as ImageBrightness, ImageChannels as ImageChannels, ImageCheckerboard as ImageCheckerboard, ImageClamp as ImageClamp, ImageColor as ImageColor, ImageContrast as ImageContrast, ImageConvolve as ImageConvolve, ImageCrop as ImageCrop, ImageDefocus as ImageDefocus, ImageDistort as ImageDistort, ImageExposure as ImageExposure, ImageFade as ImageFade, ImageGamma as ImageGamma, ImageInvert as ImageInvert, ImageLevels as ImageLevels, ImageMatteMix as ImageMatteMix, ImageMerge as ImageMerge, ImageMix as ImageMix, ImageOrient as ImageOrient, ImagePlane as ImagePlane, ImagePosition as ImagePosition, ImagePremultiply as ImagePremultiply, ImageRamp as ImageRamp, ImageRead as ImageRead, ImageReformat as ImageReformat, ImageSaturation as ImageSaturation, ImageText as ImageText, ImageThreshold as ImageThreshold, ImageUnpremultiply as ImageUnpremultiply, ImageWrite as ImageWrite, ImageZMerge as ImageZMerge, Nodes3D as Nodes3D, OCIOCDLTransform as OCIOCDLTransform, OCIOColorSpace as OCIOColorSpace, OCIODisplay as OCIODisplay, OCIOFileTransform as OCIOFileTransform, OCIOLogConvert as OCIOLogConvert, OCIOLookTransform as OCIOLookTransform, Render as Render, Transform2D as Transform2D
from typing import Set, Tuple



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtCore
import PyQt5.QtWidgets
import QT4Widgets as QT4Widgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import UI4 as UI4
import Utils as Utils
from UI4.Widgets.RolloverPixmap import RolloverPixmap as RolloverPixmap
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class PanelWidget(PyQt5.QtWidgets.QWidget):
    class CloseBoxButton(RolloverPixmap, PyQt5.QtWidgets.QPushButton):
        def __init__(self, parent) -> None: ...

    class DragBox(RolloverPixmap, PyQt5.QtWidgets.QLabel):
        dragBoxContextMenu: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
        def __init__(self, parent) -> None: ...
        def _DragBox__processDrag(self): ...
        def _resetAfterDrag(self): ...
        def contextMenuEvent(self, ev): ...
        def mousePressEvent(self, ev): ...
        def setIdentifier(self, identifier): ...
        def setWidgetSource(self, source): ...

    class IgnoreLabel(PyQt5.QtWidgets.QLabel):
        _IgnoreLabel__polygon: ClassVar[None] = ...
        def __init__(self, parent) -> None: ...

    class ZoomBox(RolloverPixmap, PyQt5.QtWidgets.QPushButton):
        def __init__(self, parent) -> None: ...
    dragBoxContextMenu: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    panelDeleted: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    panelDragInProgress: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    panelValueChanged: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, parent, name, argdict: Incomplete | None = ...) -> None: ...
    def _PanelWidget__closeBoxCallback(self): ...
    def _PanelWidget__idle_callback(self, *args, **kwargs): ...
    def _PanelWidget__zoomBoxCallback(self): ...
    def aboutToBeDeleted(self): ...
    def added(self): ...
    def event(self, e): ...
    def getCloseBox(self): ...
    def getContentArea(self): ...
    def getDragBox(self): ...
    def getFormWidgetParent(self): ...
    def getIndex(self): ...
    def getLabel(self): ...
    def getName(self): ...
    def getTitleBar(self): ...
    def getTitleBarLeft(self): ...
    def getTitleBarRight(self): ...
    def getTitlePreLabel(self): ...
    def getValue(self): ...
    def isIgnoreable(self): ...
    def isIgnored(self): ...
    def paintEvent(self, event): ...
    def resizeEvent(self, e): ...
    def sendChange(self): ...
    def setFormWidgetParent(self, parent): ...
    def setIgnoreable(self, value): ...
    def setIgnored(self, value): ...
    def setIndex(self, index): ...
    def setLocked(self, state): ...
    def setName(self, name): ...
    def setZoomBoxVisible(self, state): ...
    def zoomBoxClicked(self): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import KatanaResources as KatResourceFiles
import QT4Widgets as QT4Widgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import ResourceFiles as ResourceFiles
import Utils as Utils
from ResourceFiles.IconManager import ResourceManager as ResourceManager
from typing import Set, Tuple



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtCore
import PyQt5.QtGui
import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtWidgets as QtWidgets
from typing import ClassVar, Set, Tuple

class AttributeDropLabel(PyQt5.QtWidgets.QLabel):
    attrDropped: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    attrDroppedWithCoAttributes: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    attrDroppedWithScenegraphPath: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, parent: PyQt5.QtWidgets.QWidget | None) -> None: ...
    def dragEnterEvent(self, event: PyQt5.QtGui.QDragEnterEvent): ...
    def dropEvent(self, event: PyQt5.QtGui.QDropEvent): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtGui
import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
from UI4.Widgets.BaseLayoutResizer import BaseLayoutResizer as BaseLayoutResizer
from typing import Set, Tuple

class HBoxLayoutResizer(BaseLayoutResizer):
    def __init__(self, targetWidget: PyQt5.QtWidgets.QWidget, initialTargetWidgetWidth: int = ..., minimumTargetWidgetWidth: int = ..., beforeTargetWidget: bool = ...) -> None: ...
    def mouseMoveEvent(self, event: PyQt5.QtGui.QMouseEvent): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from _typeshed import Incomplete
from typing import Set, Tuple

class KeyboardShortcutItem:
    def __init__(self, name: str, data: dict, parent: Incomplete | None = ...) -> None: ...
    def _setParent(self, parent: KeyboardShortcutItem | None): ...
    def appendChild(self, child: KeyboardShortcutItem | None): ...
    def getChildByRow(self, row: int) -> KeyboardShortcutItem | None: ...
    def getCurrentShortcut(self) -> str: ...
    def getDefaultShortcut(self) -> str: ...
    def getID(self) -> str: ...
    def getName(self) -> str: ...
    def getParent(self) -> KeyboardShortcutItem: ...
    def getRowOfChild(self, child: KeyboardShortcutItem) -> int: ...
    def sort(self): ...
    def __len__(self) -> int: ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import UI4.Util.AttributeHistory as AttributeHistory
import UI4.Util.IconManager as IconManager
import NodegraphAPI as NodegraphAPI
import PyQt5.QtCore
import QT4FormWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtWidgets as QtWidgets
import Nodes3DAPI.ScenegraphManager as ScenegraphManager
import UI4 as UI4
import Utils as Utils
from _typeshed import Incomplete
from typing import Set, Tuple

MENU_CONTENTS_EXISTING: int
MENU_CONTENTS_NEW: int

def AddMimeData(mimeData: PyQt5.QtCore.QMimeData, locationPolicy: QT4FormWidgets.AbstractValuePolicy): ...
def CheckMimeData(mimeData: PyQt5.QtCore.QMimeData, allowNodes: bool = ...) -> PyQt5.QtCore.DropAction: ...
def FillMenu(menu, locationPolicy, contents: Incomplete | None = ..., adjustRelativeTo: Incomplete | None = ..., locked: bool = ..., basePath: bool = ..., adoptScenegraphSelectionEnabled: bool = ...): ...
def FilterLocationPath(unverifiedPath, allowRelative: bool = ...): ...
def GetNodesCreatingSceneGraphLocations(nodes: list[nodes]) -> list[node, str]: ...
def GetReferencingInfo(locationPolicy): ...
def SelectInScenegraph(locationPath: str): ...
def SetMimeData(mimeData, locationPolicy, allowNodes: bool = ...): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import Nodes2DAPI as Nodes2DAPI
from . import App as App, FormMaster as FormMaster, KatanaPrefs as KatanaPrefs, MainUI as MainUI, Manifest as Manifest, NodeMaster as NodeMaster, Tabs as Tabs, Util as Util, Widgets as Widgets
from typing import Set, Tuple



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtCore
import QT4Widgets as QT4Widgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import ResourceFiles as ResourceFiles
from QT4Widgets.FilterablePopupButton import FilterablePopupButton
from ResourceFiles.IconManager import ResourceManager as ResourceManager
from typing import ClassVar, Set, Tuple

class NonexclusiveCheckboxPopup(FilterablePopupButton):
    valuesChanged: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, parent, emptyLabel: str = ...) -> None: ...
    def _NonexclusiveCheckboxPopup__itemChosen(self, name, meta): ...
    def _NonexclusiveCheckboxPopup__popupClosed(self): ...
    def _NonexclusiveCheckboxPopup__setItemCheck(self, item): ...
    def _NonexclusiveCheckboxPopup__treeCheckboxItem(self, event): ...
    def _NonexclusiveCheckboxPopup__treeMouseMoveEvent(self, event): ...
    def _NonexclusiveCheckboxPopup__treeMousePressEvent(self, event): ...
    def _NonexclusiveCheckboxPopup__treeMouseReleaseEvent(self, event): ...
    def addItem(self, *args, **kwds): ...
    def clear(self): ...
    def getValues(self): ...
    def setValues(self, values, updateItems: bool = ..., sendSignal: bool = ..., force: bool = ...): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from typing import Set, Tuple

def exportConfiguration() -> dict[str, str]: ...
def get(key: str) -> str: ...
def has(key: str) -> bool: ...
def set(key: str, value: str) -> None: ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtGui as QtGui
from typing import Set, Tuple

DEFAULT: int
DEFAULT_REFERENCE: int
DELETE_LOCAL: int
FORCE_DEFAULT: int
FORCE_GLOBAL: int
GLOBAL: int
GLOBAL_DEFAULT_REFERENCE: int
INCOMING_LOCAL: int
LIVE: int
LOCAL: int
LOCAL_MULTI: int

def GetStateAppearance(state): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyFnAttribute
from typing import Set, Tuple

def GetHintGroup(inputAttr: PyFnAttribute.Attribute) -> PyFnAttribute.GroupAttribute: ...
def ParseConditionalStateGrammar(inputExpr: str, prefix: str = ..., secondaryPrefix: str = ...) -> PyFnAttribute.GroupAttribute: ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import Utils as Utils
from typing import Set, Tuple

def flush(isNodeGraphLoading: bool = ...): ...
def registerFlushCallback(fnc, post: bool = ...): ...
def setDirty(): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import QT4FormWidgets.InputWidgets as InputWidgets
import NodegraphAPI
import QT4FormWidgets as QT4FormWidgets
import PyQt5.QtWidgets as QtWidgets
import UI4.Widgets.SortablePanel
import Utils as Utils
from UI4.Widgets.SortablePanel import SortablePanelBase as SortablePanelBase, SortablePanelFormWidget as SortablePanelFormWidget
from typing import Set, Tuple

class InputPanel(UI4.Widgets.SortablePanel.SortablePanelBase):
    def __init__(self, parent, name) -> None: ...
    def _InputPanel__valueChangedCallback(self): ...
    def getName(self): ...
    def setName(self, name): ...

class PortNameAndOrderWidget(UI4.Widgets.SortablePanel.SortablePanelFormWidget):
    def __init__(self, parent, policy) -> None: ...
    def _PortNameAndOrderWidget__idle_callback(self, *args, **kwargs): ...
    def _PortNameAndOrderWidget__node_addOrRemoveInputPort_cb(self, eventType, eventID, nodeName, portName, port: NodegraphAPI.Port, **kwargs): ...
    def _PortNameAndOrderWidget__node_renameInputPort_cb(self, eventType, eventID, **kwargs): ...
    def _PortNameAndOrderWidget__registerEventHandlers(self): ...
    def _PortNameAndOrderWidget__unregisterEventHandlers(self): ...
    def _PortNameAndOrderWidget__update(self): ...
    def _freeze(self): ...
    def _thaw(self): ...
    def addInput(self): ...
    def buildAddMenu(self, menu): ...
    def panelDeleted(self, index): ...
    def panelReordered(self, oldPos, newPos): ...
    def renamePort(self, oldName, newName): ...
